/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_FL3NGR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_FL3NGR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_FL3NGR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FL3NGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FL3NGR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_FL3NGR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FL3NGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FL3NGR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_FL3NGR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_FL3NGR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_FL3NGR::Heavy_WSTD_FL3NGR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_rrRAyd3l);
  numBytes += sLine_init(&sLine_twZiGgGN);
  numBytes += sLine_init(&sLine_MqKv7Eak);
  numBytes += sLine_init(&sLine_76RpBgLX);
  numBytes += sLine_init(&sLine_D77gyQTR);
  numBytes += sBiquad_init(&sBiquad_s_YU3VCAIj);
  numBytes += sLine_init(&sLine_neD3RYMP);
  numBytes += sLine_init(&sLine_lKSAJPHL);
  numBytes += sLine_init(&sLine_CtYixTqs);
  numBytes += sLine_init(&sLine_AnilS9Bf);
  numBytes += sBiquad_init(&sBiquad_s_6BOoTdpM);
  numBytes += sLine_init(&sLine_mHoht1b8);
  numBytes += sLine_init(&sLine_E6pS4mir);
  numBytes += sLine_init(&sLine_tjPS3d21);
  numBytes += sLine_init(&sLine_yiREDD1z);
  numBytes += sLine_init(&sLine_j7WLhYOK);
  numBytes += sBiquad_init(&sBiquad_s_uNLP8QPK);
  numBytes += sLine_init(&sLine_3BcjWn4U);
  numBytes += sLine_init(&sLine_Ew6SYNmj);
  numBytes += sLine_init(&sLine_g7ayiPgm);
  numBytes += sLine_init(&sLine_H9eeAmXw);
  numBytes += sLine_init(&sLine_MKlYNoSv);
  numBytes += sBiquad_init(&sBiquad_s_CMepDkNH);
  numBytes += sLine_init(&sLine_4SbpfdPS);
  numBytes += sLine_init(&sLine_Y7i0X1u3);
  numBytes += sLine_init(&sLine_BWuJnSTy);
  numBytes += sLine_init(&sLine_3NGDH9nc);
  numBytes += sBiquad_init(&sBiquad_s_Q5s7tPlE);
  numBytes += sLine_init(&sLine_lzNGt3BA);
  numBytes += sLine_init(&sLine_XTM74WSO);
  numBytes += sLine_init(&sLine_ok0C4HoQ);
  numBytes += sLine_init(&sLine_mdCI1r9J);
  numBytes += sLine_init(&sLine_PiO2EgoH);
  numBytes += sBiquad_init(&sBiquad_s_85U6p8kQ);
  numBytes += sLine_init(&sLine_mOw1kwCd);
  numBytes += sPhasor_k_init(&sPhasor_y3pWWMry, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_XH1YjBX4);
  numBytes += sRPole_init(&sRPole_Y7IOTK6N);
  numBytes += sRPole_init(&sRPole_4md2bTWF);
  numBytes += sTabhead_init(&sTabhead_OYW43Ixx, &hTable_9htYfx5P);
  numBytes += sTabread_init(&sTabread_Z969HtnV, &hTable_9htYfx5P, false);
  numBytes += sTabread_init(&sTabread_MIASwqWl, &hTable_9htYfx5P, false);
  numBytes += sLine_init(&sLine_n95iWa1G);
  numBytes += sTabhead_init(&sTabhead_mQrTt0BC, &hTable_3dL54QM2);
  numBytes += sTabread_init(&sTabread_LwbJZoDJ, &hTable_3dL54QM2, false);
  numBytes += sTabread_init(&sTabread_yOBLvSC9, &hTable_3dL54QM2, false);
  numBytes += sLine_init(&sLine_7lTxxPuX);
  numBytes += sTabwrite_init(&sTabwrite_UGbqCpQu, &hTable_3dL54QM2);
  numBytes += sTabwrite_init(&sTabwrite_QEAJ4geC, &hTable_9htYfx5P);
  numBytes += sLine_init(&sLine_WUTeUERH);
  numBytes += sPhasor_k_init(&sPhasor_A0zp7kID, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_kWehlBE9);
  numBytes += sRPole_init(&sRPole_1z4Q12Sg);
  numBytes += sRPole_init(&sRPole_DVU04Yib);
  numBytes += sTabhead_init(&sTabhead_euHUqoxN, &hTable_rsLnTmTc);
  numBytes += sTabread_init(&sTabread_99mARNEn, &hTable_rsLnTmTc, false);
  numBytes += sTabread_init(&sTabread_x1M9b0nv, &hTable_rsLnTmTc, false);
  numBytes += sLine_init(&sLine_WYDF5Jh2);
  numBytes += sTabhead_init(&sTabhead_nidvomRH, &hTable_4mO83VX8);
  numBytes += sTabread_init(&sTabread_bNBDYjl0, &hTable_4mO83VX8, false);
  numBytes += sTabread_init(&sTabread_yIzEOlF2, &hTable_4mO83VX8, false);
  numBytes += sLine_init(&sLine_AD6NOWBN);
  numBytes += sTabwrite_init(&sTabwrite_scy2FQ2c, &hTable_4mO83VX8);
  numBytes += sTabwrite_init(&sTabwrite_iCvHHwZP, &hTable_rsLnTmTc);
  numBytes += sLine_init(&sLine_iAymR6PP);
  numBytes += sPhasor_k_init(&sPhasor_gDVwjPQv, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_uVEHIEzW);
  numBytes += sRPole_init(&sRPole_Qqu152HM);
  numBytes += sRPole_init(&sRPole_xNmNNzat);
  numBytes += sTabhead_init(&sTabhead_olOAcrwO, &hTable_P0hGe6xa);
  numBytes += sTabread_init(&sTabread_bJT3oNrx, &hTable_P0hGe6xa, false);
  numBytes += sTabread_init(&sTabread_CLgoSV0t, &hTable_P0hGe6xa, false);
  numBytes += sLine_init(&sLine_FmeKWVor);
  numBytes += sTabhead_init(&sTabhead_IA5d9Xyx, &hTable_SXSxbArH);
  numBytes += sTabread_init(&sTabread_7C100urG, &hTable_SXSxbArH, false);
  numBytes += sTabread_init(&sTabread_MXK7JNEF, &hTable_SXSxbArH, false);
  numBytes += sLine_init(&sLine_NKY5izPI);
  numBytes += sTabwrite_init(&sTabwrite_C4GeiriC, &hTable_SXSxbArH);
  numBytes += sTabwrite_init(&sTabwrite_vAGiRPVF, &hTable_P0hGe6xa);
  numBytes += cVar_init_f(&cVar_yoVWPTJx, 0.0f);
  numBytes += cVar_init_f(&cVar_vTEJvdDw, 0.0f);
  numBytes += cVar_init_f(&cVar_DSVCDksn, 0.0f);
  numBytes += cVar_init_f(&cVar_GugVWXAJ, 0.0f);
  numBytes += cSlice_init(&cSlice_jYJQTTCr, 1, -1);
  numBytes += cVar_init_f(&cVar_clJmT6Nq, 1337.0f);
  numBytes += cVar_init_f(&cVar_AdIgIaX1, 0.0f);
  numBytes += cIf_init(&cIf_nbsrO5hX, false);
  numBytes += cIf_init(&cIf_ONhSxCtz, false);
  numBytes += cBinop_init(&cBinop_3WnXwlAu, 0.0f); // __pow
  numBytes += cIf_init(&cIf_Gx5IDLlk, false);
  numBytes += cBinop_init(&cBinop_C1XYFIE8, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_OLtJHC2z, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_6WAbpaa2, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_1lKan4ib, 0.0f);
  numBytes += cIf_init(&cIf_haXkEkeq, false);
  numBytes += cIf_init(&cIf_E7iO4gey, false);
  numBytes += cBinop_init(&cBinop_cbDjjf9D, 0.0f); // __pow
  numBytes += cIf_init(&cIf_aCao1qtX, false);
  numBytes += cBinop_init(&cBinop_QZt6WueS, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_Lw3uMhB1, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_qJNdwjdW, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_WKqpXfaR, 0.0f);
  numBytes += cIf_init(&cIf_gYK1PhAP, false);
  numBytes += cIf_init(&cIf_RxnG1Fii, false);
  numBytes += cBinop_init(&cBinop_DKz0Qc0w, 0.0f); // __pow
  numBytes += cIf_init(&cIf_D9wLGYL1, false);
  numBytes += cBinop_init(&cBinop_0SlcOJ5N, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_uxNgz7B8, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_HKUEJkf7, -15.0f); // __eq
  numBytes += cIf_init(&cIf_LzSnUe5m, false);
  numBytes += cSlice_init(&cSlice_YQck3VHj, 1, -1);
  numBytes += cVar_init_f(&cVar_CzCUVwT1, 0.0f);
  numBytes += cSlice_init(&cSlice_Hvcn8fNh, 1, -1);
  numBytes += cVar_init_f(&cVar_OUWuvFRo, 0.0f);
  numBytes += cSlice_init(&cSlice_XLIFNFnX, 1, -1);
  numBytes += cVar_init_f(&cVar_xltjn71p, 0.0f);
  numBytes += cSlice_init(&cSlice_5gq2DFxE, 1, -1);
  numBytes += cVar_init_f(&cVar_FZJOOl6O, 0.313f);
  numBytes += cBinop_init(&cBinop_HInPSltc, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_5ApMf8he, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_IV4bTt7t, 0.0f);
  numBytes += cVar_init_f(&cVar_QNPB1AO9, 1337.0f);
  numBytes += cVar_init_f(&cVar_CoiCCvL4, 0.3f);
  numBytes += cBinop_init(&cBinop_PtgtWpTU, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_NzPConWS, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_bs4ngYJU, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_5KpopiZl, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_DfAgb6vm, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_YqtTlkkn, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_XlbOpm26, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_nPxVi2UJ, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_isYd5jXw, 0.0f);
  numBytes += cVar_init_f(&cVar_gxErFJL6, 1337.0f);
  numBytes += cVar_init_f(&cVar_7b0KbzAa, 0.313f);
  numBytes += cBinop_init(&cBinop_zgVTbFNY, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_kxegmS1m, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_8q5wPkbW, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_yrhzEym1, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_XAPhpAEx, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_CNRtsGg9, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_o29e8ALD, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_QUtbryJw, 0.0f);
  numBytes += cVar_init_f(&cVar_VCFrLnMg, 1037.0f);
  numBytes += cVar_init_f(&cVar_xeL2P4Yq, 0.4f);
  numBytes += cBinop_init(&cBinop_90MZF72O, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_gjZvn0zx, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_7VWXnLC8, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_NByVdGUU, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_fvAp0Yyf, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_9QVaf0cf, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_mtnYvZby, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_6puHlmZj, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_noslubGs, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_c5O5LlGj, 1, -1);
  numBytes += cVar_init_f(&cVar_NCnUVkFf, 1337.0f);
  numBytes += cVar_init_f(&cVar_Lv8bLzZK, 0.0f);
  numBytes += cIf_init(&cIf_Q3d6tinQ, false);
  numBytes += cIf_init(&cIf_nhlm9DiA, false);
  numBytes += cBinop_init(&cBinop_L0qNV7fR, 0.0f); // __pow
  numBytes += cIf_init(&cIf_nYaiINlO, false);
  numBytes += cBinop_init(&cBinop_b3orwX4Z, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_dryjOxdg, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_BWNY1FXf, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_uJH3jpdw, 0.0f);
  numBytes += cIf_init(&cIf_ye72ZzjV, false);
  numBytes += cIf_init(&cIf_nnKkQ8dJ, false);
  numBytes += cBinop_init(&cBinop_N5YaBdX0, 0.0f); // __pow
  numBytes += cIf_init(&cIf_YSQ9EFFC, false);
  numBytes += cBinop_init(&cBinop_cA6zUkN2, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_BllF7PO7, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_1JczFUTc, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_NVB2qh9z, 0.0f);
  numBytes += cIf_init(&cIf_kbY4oBp2, false);
  numBytes += cIf_init(&cIf_DpBFk1iJ, false);
  numBytes += cBinop_init(&cBinop_IyHOdyeF, 0.0f); // __pow
  numBytes += cIf_init(&cIf_eOE9yaxP, false);
  numBytes += cBinop_init(&cBinop_9tNcOcJt, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_46GVFoaV, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_A0MniN55, -15.0f); // __eq
  numBytes += cIf_init(&cIf_DFZ7qldW, false);
  numBytes += cSlice_init(&cSlice_X39Wn8iZ, 1, -1);
  numBytes += cVar_init_f(&cVar_D5tSHeSi, 0.0f);
  numBytes += cSlice_init(&cSlice_BPvsPy7q, 1, -1);
  numBytes += cVar_init_f(&cVar_IuddAgUM, 0.0f);
  numBytes += cSlice_init(&cSlice_m0c26eU1, 1, -1);
  numBytes += cVar_init_f(&cVar_zpAHh18r, 0.0f);
  numBytes += cSlice_init(&cSlice_rh2vxvXO, 1, -1);
  numBytes += cVar_init_f(&cVar_XEsqA6A3, 0.313f);
  numBytes += cBinop_init(&cBinop_y0wpXSxQ, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_WyEBj3pe, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_1gye7lH3, 0.0f);
  numBytes += cVar_init_f(&cVar_V4ABWl9u, 1337.0f);
  numBytes += cVar_init_f(&cVar_sp6rc319, 0.3f);
  numBytes += cBinop_init(&cBinop_kEcCk9Rq, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_oIha7pVK, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_HzgQxxlp, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_vOJSdYsM, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_gG2Ei2fy, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_gbUkgEZk, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_jrzchlun, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_TIgUSh4y, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_dcSAAFTy, 0.0f);
  numBytes += cVar_init_f(&cVar_SkdJY9ci, 1337.0f);
  numBytes += cVar_init_f(&cVar_82821BI6, 0.313f);
  numBytes += cBinop_init(&cBinop_VlvsT3E5, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_TZjzXUhV, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_y1SVgDFp, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_aUXWSFhv, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_JcWds1z5, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_X1DxxJON, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_ThNv1u6p, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_W8htIcMm, 0.0f);
  numBytes += cVar_init_f(&cVar_VNE6V6kb, 1037.0f);
  numBytes += cVar_init_f(&cVar_nZKePTKl, 0.4f);
  numBytes += cBinop_init(&cBinop_LwzrzpXc, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_TlJGu5s5, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_rQXlnmqP, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_gAw19p1C, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_P46G9i7J, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_fS8R4h4e, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_HJHEcp1I, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rGPVjyHQ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_dykhsmge, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_6tBSl4YM, 5705.6f);
  numBytes += cVar_init_f(&cVar_sojaGYME, 313.3f);
  numBytes += cBinop_init(&cBinop_Y58LRnKh, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_E0qh3bxh, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_YexD18JJ, 0.0f); // __div
  numBytes += cVar_init_f(&cVar_jM2guV0z, 0.0f);
  numBytes += cVar_init_f(&cVar_EgAOI3MD, 0.0f);
  numBytes += cVar_init_f(&cVar_SNy4gAMW, 0.0f);
  numBytes += cVar_init_f(&cVar_2yc68acT, 0.0f);
  numBytes += cVar_init_f(&cVar_mlK4c5f2, 0.0f);
  numBytes += cVar_init_f(&cVar_96KIEGzE, 0.0f);
  numBytes += cVar_init_f(&cVar_ZlRhaVem, 0.0f);
  numBytes += cVar_init_f(&cVar_quzCnWZC, 0.0f);
  numBytes += cVar_init_f(&cVar_vAbtBSvo, 0.0f);
  numBytes += cVar_init_f(&cVar_wI7SaFpj, 0.0f);
  numBytes += cVar_init_f(&cVar_R710PoNs, 0.0f);
  numBytes += cVar_init_f(&cVar_COrBuNuK, 0.0f);
  numBytes += cVar_init_s(&cVar_Kb0Ni9zK, "del-1348-flanger-l");
  numBytes += sVarf_init(&sVarf_FzNRzPa6, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_TLDNkXzt, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_hBXmsBJy, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_qCb3MdoT, "del-1348-flanger-r");
  numBytes += sVarf_init(&sVarf_wtBPylsH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_gVqyuPUw, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_OTz5TTiU, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_aIQQshRH, 0.0f);
  numBytes += cDelay_init(this, &cDelay_7CGrocz0, 0.0f);
  numBytes += hTable_init(&hTable_3dL54QM2, 256);
  numBytes += cDelay_init(this, &cDelay_xJHL47Rm, 0.0f);
  numBytes += cDelay_init(this, &cDelay_HgoMIafE, 0.0f);
  numBytes += hTable_init(&hTable_9htYfx5P, 256);
  numBytes += cVar_init_f(&cVar_TvHqzfoc, 14.0f);
  numBytes += cBinop_init(&cBinop_rcI0aHfR, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_c6CGK9o7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_0U5u95Cz, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_2Hhje5VL, 14.0f);
  numBytes += cBinop_init(&cBinop_WV2BqaLT, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_Qt0A8i22, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_eejh9GHF, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_5FkV8POZ, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_LXcGdTkb, 1, -1);
  numBytes += cVar_init_f(&cVar_uTG9mwC1, 0.2f);
  numBytes += cSlice_init(&cSlice_fBguEFAl, 1, -1);
  numBytes += cVar_init_f(&cVar_M1TVNkcR, 0.0f);
  numBytes += cSlice_init(&cSlice_eSos4r8M, 1, -1);
  numBytes += cVar_init_f(&cVar_Hwby63Uh, 2.0f);
  numBytes += cSlice_init(&cSlice_AS15WsvD, 1, -1);
  numBytes += cVar_init_f(&cVar_UAETENPN, 0.5f);
  numBytes += cVar_init_s(&cVar_uYEr6xUh, "del-1397-flanger-l");
  numBytes += sVarf_init(&sVarf_LlRku39s, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rYNkRQIl, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_l9TUCfS0, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_xKuXDpCU, "del-1397-flanger-r");
  numBytes += sVarf_init(&sVarf_2p7296fN, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_uICnLuHu, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_b5hegUeA, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_IAHkcw2b, 0.0f);
  numBytes += cDelay_init(this, &cDelay_OFmXlRco, 0.0f);
  numBytes += hTable_init(&hTable_4mO83VX8, 256);
  numBytes += cDelay_init(this, &cDelay_z0om9l53, 0.0f);
  numBytes += cDelay_init(this, &cDelay_EgBGY2oD, 0.0f);
  numBytes += hTable_init(&hTable_rsLnTmTc, 256);
  numBytes += cVar_init_f(&cVar_LKWNK3iH, 14.0f);
  numBytes += cBinop_init(&cBinop_sb0Im6y8, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_0MPkzyKO, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_RdY48TDT, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_H8AluwqR, 14.0f);
  numBytes += cBinop_init(&cBinop_KXIDPjmA, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_Pcy1dl4X, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_neGDFWv3, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_aiH7zy8B, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_HbX7Rult, 1, -1);
  numBytes += cVar_init_f(&cVar_tl94wXNj, 0.2f);
  numBytes += cSlice_init(&cSlice_KLb2IysI, 1, -1);
  numBytes += cVar_init_f(&cVar_Kkch5TV6, 0.0f);
  numBytes += cSlice_init(&cSlice_tlj1gLuJ, 1, -1);
  numBytes += cVar_init_f(&cVar_ZeaSYo0A, 2.0f);
  numBytes += cSlice_init(&cSlice_7W4yCwpp, 1, -1);
  numBytes += cVar_init_f(&cVar_zCZLRCnr, 0.5f);
  numBytes += cVar_init_s(&cVar_Vq2UwYeb, "del-1446-flanger-l");
  numBytes += sVarf_init(&sVarf_h6rZl739, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_yAN3DImb, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_y51AZSzI, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_g3sRcTjp, "del-1446-flanger-r");
  numBytes += sVarf_init(&sVarf_LUnfpqnN, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fJlfZtxT, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_hLYhbnsF, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_aAD1Dg5N, 0.0f);
  numBytes += cDelay_init(this, &cDelay_gxzh1X3B, 0.0f);
  numBytes += hTable_init(&hTable_SXSxbArH, 256);
  numBytes += cDelay_init(this, &cDelay_DdS4t9qx, 0.0f);
  numBytes += cDelay_init(this, &cDelay_cYgOquOR, 0.0f);
  numBytes += hTable_init(&hTable_P0hGe6xa, 256);
  numBytes += cVar_init_f(&cVar_PEeEoTRV, 14.0f);
  numBytes += cBinop_init(&cBinop_2j703k2a, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_fzlq2bHd, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Ry6ZqjKU, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_GxjBsKeQ, 14.0f);
  numBytes += cBinop_init(&cBinop_UZVGln91, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_jzmkHT9k, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_iu7zgJ13, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_rCp0aTKB, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_82NJIwge, 1, -1);
  numBytes += cVar_init_f(&cVar_cq1esJeH, 0.2f);
  numBytes += cSlice_init(&cSlice_gXc15SE9, 1, -1);
  numBytes += cVar_init_f(&cVar_ZKRObMeT, 0.0f);
  numBytes += cSlice_init(&cSlice_wsWW3Mmj, 1, -1);
  numBytes += cVar_init_f(&cVar_e2M7ElJd, 2.0f);
  numBytes += cSlice_init(&cSlice_dVIU4wlx, 1, -1);
  numBytes += cVar_init_f(&cVar_WHafkyuK, 0.5f);
  numBytes += sVarf_init(&sVarf_tSQtPspG, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_O8XggNXK, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_jokIo9ta, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_PwOTWyeZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_xuNyUIJk, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_0oGBtuHn, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_FL3NGR::~Heavy_WSTD_FL3NGR() {
  hTable_free(&hTable_3dL54QM2);
  hTable_free(&hTable_9htYfx5P);
  hTable_free(&hTable_4mO83VX8);
  hTable_free(&hTable_rsLnTmTc);
  hTable_free(&hTable_SXSxbArH);
  hTable_free(&hTable_P0hGe6xa);
}

HvTable *Heavy_WSTD_FL3NGR::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x7E84AE7C: return &hTable_3dL54QM2; // del-1348-flanger-r
    case 0x8BC7EF65: return &hTable_9htYfx5P; // del-1348-flanger-l
    case 0x67C454D4: return &hTable_4mO83VX8; // del-1397-flanger-r
    case 0x578173CB: return &hTable_rsLnTmTc; // del-1397-flanger-l
    case 0xB5F31EFF: return &hTable_SXSxbArH; // del-1446-flanger-r
    case 0xFB92DE56: return &hTable_P0hGe6xa; // del-1446-flanger-l
    default: return nullptr;
  }
}

void Heavy_WSTD_FL3NGR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5EJwOSEv_sendMessage);
      break;
    }
    case 0xACE44B9C: { // High_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qZjtV9eP_sendMessage);
      break;
    }
    case 0xA66E154B: { // High_Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_W4WXti8o_sendMessage);
      break;
    }
    case 0xAC5FA57F: { // High_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_O5f2g90P_sendMessage);
      break;
    }
    case 0x49068FB0: { // High_Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GgcntOSp_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lHzQsKQp_sendMessage);
      break;
    }
    case 0xDDAB7A0: { // Low_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3qTsLV7b_sendMessage);
      break;
    }
    case 0xF8FE7D54: { // Low_Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tWpfWKUV_sendMessage);
      break;
    }
    case 0x91FEF7A: { // Low_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Esx5cZUy_sendMessage);
      break;
    }
    case 0x768962E9: { // Low_Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xAX4PBsL_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Vx2Hnu5p_sendMessage);
      break;
    }
    case 0x9B44FA2D: { // Mid_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MDcRHa4j_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hXpY2LJD_sendMessage);
      break;
    }
    case 0x30AE5EFB: { // Mid_Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KiPw5DIC_sendMessage);
      break;
    }
    case 0x676FE235: { // Mid_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5oRQooY3_sendMessage);
      break;
    }
    case 0x78CC8F6D: { // Mid_Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_leVCLEx6_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Cwkgepyw_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_R0ihYpZ3_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WUbKR1mq_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uWs5Z8ZH_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LgRTMi5G_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UILGO926_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UBUSRrY9_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XljBVIzq_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tiEe4one_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QUZSafhF_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fTKKzfZa_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_37EK88Zr_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SVF7dnRB_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KXJmXbHe_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qLe4iSd0_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3xwlnTFE_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sPZIURtY_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PChKCR7d_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cufhi6NL_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_y0Ag82V1_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gYpqnUr5_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1YMI8Ry6_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hPLvPMer_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fFJag43t_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fgJIGKM7_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_R4cruUEO_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Lq7Coeq1_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GWJXzfeF_sendMessage);
      break;
    }
    case 0xB9261D01: { // 1348-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DuHLNSnR_sendMessage);
      break;
    }
    case 0x7B4AB7DC: { // 1348-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_aSQUXB0X_sendMessage);
      break;
    }
    case 0xC21D5730: { // 1348-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Mn9BiI2z_sendMessage);
      break;
    }
    case 0x73E3A43F: { // 1348-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fPXIKBaG_sendMessage);
      break;
    }
    case 0x8020E246: { // 1397-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dO9arZNb_sendMessage);
      break;
    }
    case 0xDE6EF86C: { // 1397-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ydV5PWVu_sendMessage);
      break;
    }
    case 0x4C9CDCA8: { // 1397-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Uc2g3iSq_sendMessage);
      break;
    }
    case 0xB69DF8D2: { // 1397-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zzgHUNL0_sendMessage);
      break;
    }
    case 0x2ABB5D7C: { // 1446-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pJhxmfLo_sendMessage);
      break;
    }
    case 0xE9A86FE0: { // 1446-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_IIiKrnLe_sendMessage);
      break;
    }
    case 0xC66A3021: { // 1446-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_IJeuRxRH_sendMessage);
      break;
    }
    case 0x64835C2: { // 1446-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mhpqg7uO_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_iEZepmqQ_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_FL3NGR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "High_Feedback";
        info->hash = 0xACE44B9C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 2: {
        info->name = "High_Intensity";
        info->hash = 0xA66E154B;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 3: {
        info->name = "High_Mix";
        info->hash = 0xAC5FA57F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 4: {
        info->name = "High_Speed";
        info->hash = 0x49068FB0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      case 5: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 6: {
        info->name = "Low_Feedback";
        info->hash = 0xDDAB7A0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 7: {
        info->name = "Low_Intensity";
        info->hash = 0xF8FE7D54;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 8: {
        info->name = "Low_Mix";
        info->hash = 0x91FEF7A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 9: {
        info->name = "Low_Speed";
        info->hash = 0x768962E9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      case 10: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 11: {
        info->name = "Mid_Feedback";
        info->hash = 0x9B44FA2D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      case 13: {
        info->name = "Mid_Intensity";
        info->hash = 0x30AE5EFB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 14: {
        info->name = "Mid_Mix";
        info->hash = 0x676FE235;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 15: {
        info->name = "Mid_Speed";
        info->hash = 0x78CC8F6D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 16;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_FL3NGR::cVar_yoVWPTJx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Y8Nn1awi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_vTEJvdDw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qroFs8bR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_DSVCDksn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_u5zv1voK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_GugVWXAJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sF4EzBq7_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DlY5oWBA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0pNsNheM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_civB8mzX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_2ZAkuA2p_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_jYJQTTCr, 0, m, &cSlice_jYJQTTCr_sendMessage);
      break;
    }
    default: {
      cSwitchcase_7IrlioVN_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_jYJQTTCr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_U85ndWwJ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_U85ndWwJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_clJmT6Nq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_U85ndWwJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_U85ndWwJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_WUbKR1mq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_AdIgIaX1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_mBfn1q6V_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_nbsrO5hX, 0, m, &cIf_nbsrO5hX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_nbsrO5hX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_7tQjhWAZ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_ONhSxCtz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_2j1JzaDu_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_uxNzYddX_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_RZjMsGvF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_3WnXwlAu, HV_BINOP_POW, 0, m, &cBinop_3WnXwlAu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_3WnXwlAu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Gx5IDLlk, 0, m, &cIf_Gx5IDLlk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_xerM0Q7M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_rY5IbO4c_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_JtNA1ogz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ONhSxCtz, 0, m, &cIf_ONhSxCtz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_OTl9ii16_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ll90k239_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ll90k239_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ONhSxCtz, 1, m, &cIf_ONhSxCtz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_uxNzYddX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_xerM0Q7M_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_2j1JzaDu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_Gx5IDLlk, 0, m, &cIf_Gx5IDLlk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_rY5IbO4c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3WnXwlAu, HV_BINOP_POW, 1, m, &cBinop_3WnXwlAu_sendMessage);
  cMsg_RZjMsGvF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_Gx5IDLlk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_mtnYvZby, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_mBfn1q6V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nbsrO5hX, 1, m, &cIf_nbsrO5hX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_7tQjhWAZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OLtJHC2z, HV_BINOP_GREATER_THAN, 1, m, &cBinop_OLtJHC2z_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_6WAbpaa2, HV_BINOP_EQ, 1, m, &cBinop_6WAbpaa2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_2a6Y7PoD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_C1XYFIE8, HV_BINOP_ADD, 0, m, &cBinop_C1XYFIE8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_C1XYFIE8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OTl9ii16_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JtNA1ogz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_OLtJHC2z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Gx5IDLlk, 1, m, &cIf_Gx5IDLlk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_6WAbpaa2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8cwo2XL2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_8cwo2XL2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_mtnYvZby, m);
}

void Heavy_WSTD_FL3NGR::cCast_KXW3kBdp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_C1XYFIE8, HV_BINOP_ADD, 1, m, &cBinop_C1XYFIE8_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_OLtJHC2z, HV_BINOP_GREATER_THAN, 0, m, &cBinop_OLtJHC2z_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_6WAbpaa2, HV_BINOP_EQ, 0, m, &cBinop_6WAbpaa2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Men2NoAt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AdIgIaX1, 0, m, &cVar_AdIgIaX1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_fQfT6cKh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2a6Y7PoD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_1lKan4ib_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_bDzao891_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_haXkEkeq, 0, m, &cIf_haXkEkeq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_haXkEkeq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_g46grhHI_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_E7iO4gey_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_9sagHEP3_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_HrjYSnoa_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_C60EHDOl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_cbDjjf9D, HV_BINOP_POW, 0, m, &cBinop_cbDjjf9D_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_cbDjjf9D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aCao1qtX, 0, m, &cIf_aCao1qtX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_dUyAJngE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_U0LVdQT4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_fSl6N48T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_E7iO4gey, 0, m, &cIf_E7iO4gey_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ZPaOXkvQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_OgGyJIoO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_OgGyJIoO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_E7iO4gey, 1, m, &cIf_E7iO4gey_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_HrjYSnoa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_dUyAJngE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_9sagHEP3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_aCao1qtX, 0, m, &cIf_aCao1qtX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_U0LVdQT4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cbDjjf9D, HV_BINOP_POW, 1, m, &cBinop_cbDjjf9D_sendMessage);
  cMsg_C60EHDOl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_aCao1qtX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_JoLp9dn3_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_dCqL5vxp_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_N1OGkCjU_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_bDzao891_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_haXkEkeq, 1, m, &cIf_haXkEkeq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_g46grhHI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Lw3uMhB1, HV_BINOP_GREATER_THAN, 1, m, &cBinop_Lw3uMhB1_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_qJNdwjdW, HV_BINOP_EQ, 1, m, &cBinop_qJNdwjdW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_MniLHWxP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_QZt6WueS, HV_BINOP_ADD, 0, m, &cBinop_QZt6WueS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_QZt6WueS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZPaOXkvQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fSl6N48T_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Lw3uMhB1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aCao1qtX, 1, m, &cIf_aCao1qtX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qJNdwjdW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_f6ZcW4sJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_f6ZcW4sJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_JoLp9dn3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_dCqL5vxp_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_N1OGkCjU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_B3jwyw4G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QZt6WueS, HV_BINOP_ADD, 1, m, &cBinop_QZt6WueS_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Lw3uMhB1, HV_BINOP_GREATER_THAN, 0, m, &cBinop_Lw3uMhB1_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_qJNdwjdW, HV_BINOP_EQ, 0, m, &cBinop_qJNdwjdW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_mAF92Ikx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1lKan4ib, 0, m, &cVar_1lKan4ib_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_DH4GC7AQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MniLHWxP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_WKqpXfaR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_HwfwEPgA_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_gYK1PhAP, 0, m, &cIf_gYK1PhAP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_gYK1PhAP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_5HAuIggh_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_RxnG1Fii_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_fbH5FvMM_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_co1o6syM_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_kkIqLJMA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_DKz0Qc0w, HV_BINOP_POW, 0, m, &cBinop_DKz0Qc0w_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_DKz0Qc0w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_D9wLGYL1, 0, m, &cIf_D9wLGYL1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Ue3UrzTg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_RYApv7Jx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_SsGlOhON_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RxnG1Fii, 0, m, &cIf_RxnG1Fii_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_SkGLJriP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_MzeBzXMA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_MzeBzXMA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RxnG1Fii, 1, m, &cIf_RxnG1Fii_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_co1o6syM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_Ue3UrzTg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_fbH5FvMM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_D9wLGYL1, 0, m, &cIf_D9wLGYL1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_RYApv7Jx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DKz0Qc0w, HV_BINOP_POW, 1, m, &cBinop_DKz0Qc0w_sendMessage);
  cMsg_kkIqLJMA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_D9wLGYL1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_noslubGs, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_HwfwEPgA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gYK1PhAP, 1, m, &cIf_gYK1PhAP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5HAuIggh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uxNgz7B8, HV_BINOP_GREATER_THAN, 1, m, &cBinop_uxNgz7B8_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_HKUEJkf7, HV_BINOP_EQ, 1, m, &cBinop_HKUEJkf7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_q5cCRjQf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_0SlcOJ5N, HV_BINOP_ADD, 0, m, &cBinop_0SlcOJ5N_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0SlcOJ5N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SkGLJriP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SsGlOhON_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_uxNgz7B8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_D9wLGYL1, 1, m, &cIf_D9wLGYL1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_HKUEJkf7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5Q5ytNps_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_5Q5ytNps_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_noslubGs, m);
}

void Heavy_WSTD_FL3NGR::cCast_MuMrgJ3Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0SlcOJ5N, HV_BINOP_ADD, 1, m, &cBinop_0SlcOJ5N_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_uxNgz7B8, HV_BINOP_GREATER_THAN, 0, m, &cBinop_uxNgz7B8_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_HKUEJkf7, HV_BINOP_EQ, 0, m, &cBinop_HKUEJkf7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_hnrtTii9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WKqpXfaR, 0, m, &cVar_WKqpXfaR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_IKGI68xv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_q5cCRjQf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_LzSnUe5m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_6puHlmZj, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cSwitchcase_yVgsnzJi_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_YQck3VHj, 0, m, &cSlice_YQck3VHj_sendMessage);
      break;
    }
    default: {
      cSwitchcase_jlX5icC5_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_YQck3VHj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_6nyVcwKN_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_6nyVcwKN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_CzCUVwT1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_6nyVcwKN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_6nyVcwKN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Cwkgepyw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_jlX5icC5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Hvcn8fNh, 0, m, &cSlice_Hvcn8fNh_sendMessage);
      break;
    }
    default: {
      cSwitchcase_2ZAkuA2p_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_Hvcn8fNh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_oYqftyun_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_oYqftyun_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_OUWuvFRo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_oYqftyun_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_oYqftyun_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_LgRTMi5G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_7IrlioVN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_XLIFNFnX, 0, m, &cSlice_XLIFNFnX_sendMessage);
      break;
    }
    default: {
      cSwitchcase_shOLwKCn_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_XLIFNFnX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_63Qq7euE_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_63Qq7euE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_xltjn71p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_63Qq7euE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_63Qq7euE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_R0ihYpZ3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_shOLwKCn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_5gq2DFxE, 0, m, &cSlice_5gq2DFxE_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_5gq2DFxE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_xYGqtc85_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_xYGqtc85_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_FZJOOl6O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xYGqtc85_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_xYGqtc85_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_uWs5Z8ZH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_EuSEgpgh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rrRAyd3l, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_jDyJhioj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_twZiGgGN, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_KpRahaHf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MqKv7Eak, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_B1ouuqk0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_76RpBgLX, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_lW3jguQS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_D77gyQTR, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_q8KYuGZK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_pwMLSXbQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_pwMLSXbQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HInPSltc, HV_BINOP_DIVIDE, 1, m, &cBinop_HInPSltc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UzHZbJg4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_RQ3CCHK8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_ALGnOkRG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_5R6ttqiq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_RQ3CCHK8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ALGnOkRG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HInPSltc, HV_BINOP_DIVIDE, 0, m, &cBinop_HInPSltc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_UzHZbJg4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5R6ttqiq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_HInPSltc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5ApMf8he, HV_BINOP_MULTIPLY, 1, m, &cBinop_5ApMf8he_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5ApMf8he_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FWF4c2CI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6iEknivS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_kJJ6yNZV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xaKdIhtx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_vHgpjy1b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_didoUDQP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_FuZdiTBh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_vsfGtgFA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_vsfGtgFA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5ApMf8he, HV_BINOP_MULTIPLY, 0, m, &cBinop_5ApMf8he_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_yEFe8YUA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_IFxfiYW9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_IFxfiYW9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IHNgnN3A_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_CJCnb0Ch_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IV4bTt7t, 1, m, &cVar_IV4bTt7t_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_IV4bTt7t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iZzbvIcg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_EFEegEYC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NzPConWS, HV_BINOP_MULTIPLY, 1, m, &cBinop_NzPConWS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_D6tvlYq4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_EFEegEYC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_jXZPYKxN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_SL4ARiNe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_SL4ARiNe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bs4ngYJU, HV_BINOP_MULTIPLY, 1, m, &cBinop_bs4ngYJU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_KtrJYeCC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5KpopiZl, HV_BINOP_MULTIPLY, 1, m, &cBinop_5KpopiZl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0exEOhEU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_KtrJYeCC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_FcRmVZYH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DfAgb6vm, HV_BINOP_MULTIPLY, 1, m, &cBinop_DfAgb6vm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_gayYjyQz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_wmgWTi8R_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_wmgWTi8R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YqtTlkkn, HV_BINOP_MULTIPLY, 1, m, &cBinop_YqtTlkkn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_QNPB1AO9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ooyP48OZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_FuZdiTBh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xxoOnp4c_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_CoiCCvL4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_yEFe8YUA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_6iEknivS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_vHgpjy1b_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_FWF4c2CI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_kJJ6yNZV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_xaKdIhtx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_XljBVIzq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_didoUDQP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_UBUSRrY9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_lurDFAhS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_UILGO926_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_IHNgnN3A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_WwOIc68Y_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_WwOIc68Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PtgtWpTU, HV_BINOP_MULTIPLY, 1, m, &cBinop_PtgtWpTU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_PtgtWpTU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_BgItWpne_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_BgItWpne_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_lurDFAhS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_iZzbvIcg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_jH9sWgE9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_jH9sWgE9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JltbGP99_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2U06xdje_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4z016xSt_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4yaCxEzp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_afHMySiA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yuLHEWZk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_NzPConWS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EuSEgpgh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_bs4ngYJU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jDyJhioj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_5KpopiZl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KpRahaHf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_DfAgb6vm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_B1ouuqk0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_YqtTlkkn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lW3jguQS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_oIH9Sx5L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QNPB1AO9, 0, m, &cVar_QNPB1AO9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_FarNMEQZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CoiCCvL4, 1, m, &cVar_CoiCCvL4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_yuLHEWZk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NzPConWS, HV_BINOP_MULTIPLY, 0, m, &cBinop_NzPConWS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_4z016xSt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DfAgb6vm, HV_BINOP_MULTIPLY, 0, m, &cBinop_DfAgb6vm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_afHMySiA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bs4ngYJU, HV_BINOP_MULTIPLY, 0, m, &cBinop_bs4ngYJU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_2U06xdje_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YqtTlkkn, HV_BINOP_MULTIPLY, 0, m, &cBinop_YqtTlkkn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_4yaCxEzp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5KpopiZl, HV_BINOP_MULTIPLY, 0, m, &cBinop_5KpopiZl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_JltbGP99_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_ooyP48OZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CoiCCvL4, 0, m, &cVar_CoiCCvL4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_xxoOnp4c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IV4bTt7t, 0, m, &cVar_IV4bTt7t_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_krPXsu47_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_neD3RYMP, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_lYyKtRQW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lKSAJPHL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_TOkhYIvL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CtYixTqs, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_oAnpF0GT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_AnilS9Bf, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_GapA106H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_HnZVMDSv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_HnZVMDSv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XlbOpm26, HV_BINOP_DIVIDE, 1, m, &cBinop_XlbOpm26_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_x712tgYG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_aOwbO8A5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_lxdWv7x3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_2V85Ksbf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_aOwbO8A5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_lxdWv7x3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XlbOpm26, HV_BINOP_DIVIDE, 0, m, &cBinop_XlbOpm26_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_x712tgYG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2V85Ksbf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_XlbOpm26_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nPxVi2UJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_nPxVi2UJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_nPxVi2UJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Bf0o3Jtk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GkJOKtSs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_SyKL0yj9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hogVfEof_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_S8EP4T8j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hJSqSZ3o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_kQ99e7fP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_CsxLFcIT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_CsxLFcIT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nPxVi2UJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_nPxVi2UJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_EWPUQYJB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_OnGAPVAm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_OnGAPVAm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bLZlRCcT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_IIz5rCWw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8q5wPkbW, HV_BINOP_MULTIPLY, 1, m, &cBinop_8q5wPkbW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_W6s1qoDe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_isYd5jXw, 1, m, &cVar_isYd5jXw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ORih78k1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yrhzEym1, HV_BINOP_MULTIPLY, 1, m, &cBinop_yrhzEym1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_jL3gFd5E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_6OIW9z24_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_6OIW9z24_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XAPhpAEx, HV_BINOP_MULTIPLY, 1, m, &cBinop_XAPhpAEx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_isYd5jXw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1jKYABBR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_gxErFJL6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YxBHCqpj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_kQ99e7fP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FlP3uxpF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_7b0KbzAa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_EWPUQYJB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Bf0o3Jtk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_SyKL0yj9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_GkJOKtSs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_S8EP4T8j_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_hogVfEof_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_fTKKzfZa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_hJSqSZ3o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_QUZSafhF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_7yPQqmQt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_tiEe4one_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_bLZlRCcT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Wx8OXsRH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Wx8OXsRH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zgVTbFNY, HV_BINOP_MULTIPLY, 1, m, &cBinop_zgVTbFNY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_zgVTbFNY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_xWH1pGXK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_xWH1pGXK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_7yPQqmQt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_1jKYABBR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ZvKhWiht_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ZvKhWiht_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Iva00cP3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jS75ISnc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MNFbpg2g_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iZFOJ09x_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_kxegmS1m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_krPXsu47_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_8q5wPkbW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lYyKtRQW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_yrhzEym1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TOkhYIvL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_XAPhpAEx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oAnpF0GT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_103Txfqo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7b0KbzAa, 1, m, &cVar_7b0KbzAa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_gc2GDBNQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gxErFJL6, 0, m, &cVar_gxErFJL6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_FlP3uxpF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_isYd5jXw, 0, m, &cVar_isYd5jXw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_YxBHCqpj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7b0KbzAa, 0, m, &cVar_7b0KbzAa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_iZFOJ09x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kxegmS1m, HV_BINOP_MULTIPLY, 0, m, &cBinop_kxegmS1m_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Iva00cP3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XAPhpAEx, HV_BINOP_MULTIPLY, 0, m, &cBinop_XAPhpAEx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_MNFbpg2g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8q5wPkbW, HV_BINOP_MULTIPLY, 0, m, &cBinop_8q5wPkbW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_jS75ISnc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yrhzEym1, HV_BINOP_MULTIPLY, 0, m, &cBinop_yrhzEym1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_0fA15KD9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mHoht1b8, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_3qujKkoQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_E6pS4mir, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_EWjo6cPm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tjPS3d21, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_KJckxsh1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yiREDD1z, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_d5BfdAnA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_j7WLhYOK, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_pBzt9iEd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_oUeILpA2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_oUeILpA2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CNRtsGg9, HV_BINOP_DIVIDE, 1, m, &cBinop_CNRtsGg9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bX5V7pug_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_3Atv8Tu6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_eq3W4ugS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_NWxJ9wvJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_3Atv8Tu6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_eq3W4ugS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CNRtsGg9, HV_BINOP_DIVIDE, 0, m, &cBinop_CNRtsGg9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_bX5V7pug_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NWxJ9wvJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_CNRtsGg9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_o29e8ALD, HV_BINOP_MULTIPLY, 1, m, &cBinop_o29e8ALD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_o29e8ALD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9486568w_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zQBVvljZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_8x0q8Ge0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_SS0M30HA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_CZPvnFnY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_oXMfzRgE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_hJzuxTIi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_Bh8u6jK6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Bh8u6jK6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_o29e8ALD, HV_BINOP_MULTIPLY, 0, m, &cBinop_o29e8ALD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_lT2gX5pU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_QUBtBEyp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_QUBtBEyp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_l7ZLqZDO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_HENwHHQL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gjZvn0zx, HV_BINOP_MULTIPLY, 1, m, &cBinop_gjZvn0zx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_xV167CVQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_uZ0mWjyS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_uZ0mWjyS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_HENwHHQL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_lyLuVu5p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_gNLbx2b1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gNLbx2b1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7VWXnLC8, HV_BINOP_MULTIPLY, 1, m, &cBinop_7VWXnLC8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_QHMS6WmQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NByVdGUU, HV_BINOP_MULTIPLY, 1, m, &cBinop_NByVdGUU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_4ii2vutx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_gDp9k2Ew_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gDp9k2Ew_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_QHMS6WmQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_BRzULTLn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QUtbryJw, 1, m, &cVar_QUtbryJw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_1C6xrWjL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fvAp0Yyf, HV_BINOP_MULTIPLY, 1, m, &cBinop_fvAp0Yyf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_ar1HjIjP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_pUOa20c9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_pUOa20c9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9QVaf0cf, HV_BINOP_MULTIPLY, 1, m, &cBinop_9QVaf0cf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_QUtbryJw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IieTuoYN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_VCFrLnMg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_81Jz23pW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_hJzuxTIi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FEsQq0YV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_xeL2P4Yq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_lT2gX5pU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_zQBVvljZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_CZPvnFnY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_9486568w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_8x0q8Ge0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_SS0M30HA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_KXJmXbHe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_oXMfzRgE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_SVF7dnRB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_eJB7YWyb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_37EK88Zr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_l7ZLqZDO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_sI7J8y2W_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_sI7J8y2W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_90MZF72O, HV_BINOP_MULTIPLY, 1, m, &cBinop_90MZF72O_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_90MZF72O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_LRPxNgEr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_LRPxNgEr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_eJB7YWyb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_IieTuoYN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_v8NyIiPT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_v8NyIiPT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dx0BVDWW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pVBHDNFA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Z1fws8Dk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SEBcmz3W_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MtXgAfi9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3ZNZ6Wj2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gjZvn0zx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0fA15KD9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_7VWXnLC8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3qujKkoQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_NByVdGUU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EWjo6cPm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_fvAp0Yyf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KJckxsh1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_9QVaf0cf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_d5BfdAnA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_rcBKTumo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xeL2P4Yq, 1, m, &cVar_xeL2P4Yq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_bRpHZiTM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VCFrLnMg, 0, m, &cVar_VCFrLnMg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_3ZNZ6Wj2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gjZvn0zx, HV_BINOP_MULTIPLY, 0, m, &cBinop_gjZvn0zx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Z1fws8Dk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fvAp0Yyf, HV_BINOP_MULTIPLY, 0, m, &cBinop_fvAp0Yyf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_MtXgAfi9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7VWXnLC8, HV_BINOP_MULTIPLY, 0, m, &cBinop_7VWXnLC8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_pVBHDNFA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9QVaf0cf, HV_BINOP_MULTIPLY, 0, m, &cBinop_9QVaf0cf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_SEBcmz3W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NByVdGUU, HV_BINOP_MULTIPLY, 0, m, &cBinop_NByVdGUU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_dx0BVDWW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_FEsQq0YV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QUtbryJw, 0, m, &cVar_QUtbryJw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_81Jz23pW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xeL2P4Yq, 0, m, &cVar_xeL2P4Yq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_JoLp9dn3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LzSnUe5m, 1, m, &cIf_LzSnUe5m_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_2XEyRfdh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_6puHlmZj, m);
}

void Heavy_WSTD_FL3NGR::cBinop_dCqL5vxp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2XEyRfdh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_N1OGkCjU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LzSnUe5m, 0, m, &cIf_LzSnUe5m_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_7oSjmJ9b_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_c5O5LlGj, 0, m, &cSlice_c5O5LlGj_sendMessage);
      break;
    }
    default: {
      cSwitchcase_X7m6u78y_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_c5O5LlGj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Oi5erdAE_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Oi5erdAE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_NCnUVkFf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Oi5erdAE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_Oi5erdAE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_sPZIURtY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_Lv8bLzZK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_CdJsLymn_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_Q3d6tinQ, 0, m, &cIf_Q3d6tinQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_Q3d6tinQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_xlf6pp2N_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_nhlm9DiA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_VzOgzADm_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_Kzt71t5a_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_5OJlWnPK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_L0qNV7fR, HV_BINOP_POW, 0, m, &cBinop_L0qNV7fR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_L0qNV7fR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nYaiINlO, 0, m, &cIf_nYaiINlO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9RSixa3x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_xPyeH3O9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_dP41THzI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nhlm9DiA, 0, m, &cIf_nhlm9DiA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_T1nd6MPG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Lli3hPRH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Lli3hPRH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nhlm9DiA, 1, m, &cIf_nhlm9DiA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Kzt71t5a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_9RSixa3x_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_VzOgzADm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_nYaiINlO, 0, m, &cIf_nYaiINlO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_xPyeH3O9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L0qNV7fR, HV_BINOP_POW, 1, m, &cBinop_L0qNV7fR_sendMessage);
  cMsg_5OJlWnPK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_nYaiINlO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_HJHEcp1I, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_CdJsLymn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Q3d6tinQ, 1, m, &cIf_Q3d6tinQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_xlf6pp2N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dryjOxdg, HV_BINOP_GREATER_THAN, 1, m, &cBinop_dryjOxdg_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_BWNY1FXf, HV_BINOP_EQ, 1, m, &cBinop_BWNY1FXf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_mUI7hvIK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_b3orwX4Z, HV_BINOP_ADD, 0, m, &cBinop_b3orwX4Z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_b3orwX4Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_T1nd6MPG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dP41THzI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_dryjOxdg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nYaiINlO, 1, m, &cIf_nYaiINlO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_BWNY1FXf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mu3dcdlm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_mu3dcdlm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_HJHEcp1I, m);
}

void Heavy_WSTD_FL3NGR::cCast_clxEn92I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mUI7hvIK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_eo5NiluP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_b3orwX4Z, HV_BINOP_ADD, 1, m, &cBinop_b3orwX4Z_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_dryjOxdg, HV_BINOP_GREATER_THAN, 0, m, &cBinop_dryjOxdg_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_BWNY1FXf, HV_BINOP_EQ, 0, m, &cBinop_BWNY1FXf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_C186DmlN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Lv8bLzZK, 0, m, &cVar_Lv8bLzZK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_uJH3jpdw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_gAjScLlT_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_ye72ZzjV, 0, m, &cIf_ye72ZzjV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_ye72ZzjV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_9OVks7vi_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_nnKkQ8dJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_K929MN3t_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_LisJTqV4_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_iWZmuNlE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_N5YaBdX0, HV_BINOP_POW, 0, m, &cBinop_N5YaBdX0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_N5YaBdX0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YSQ9EFFC, 0, m, &cIf_YSQ9EFFC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_dfWWt0Dv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_FdEAoVKR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_P75OpBb0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Ox7ytabX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_1b2PTVlb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nnKkQ8dJ, 0, m, &cIf_nnKkQ8dJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Ox7ytabX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nnKkQ8dJ, 1, m, &cIf_nnKkQ8dJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_LisJTqV4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_dfWWt0Dv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_K929MN3t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_YSQ9EFFC, 0, m, &cIf_YSQ9EFFC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_FdEAoVKR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_N5YaBdX0, HV_BINOP_POW, 1, m, &cBinop_N5YaBdX0_sendMessage);
  cMsg_iWZmuNlE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_YSQ9EFFC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_tZ8qJGyi_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_T76GZnGl_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_85Ur08w0_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_gAjScLlT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ye72ZzjV, 1, m, &cIf_ye72ZzjV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9OVks7vi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BllF7PO7, HV_BINOP_GREATER_THAN, 1, m, &cBinop_BllF7PO7_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_1JczFUTc, HV_BINOP_EQ, 1, m, &cBinop_1JczFUTc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_J9Q4nEZD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_cA6zUkN2, HV_BINOP_ADD, 0, m, &cBinop_cA6zUkN2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_cA6zUkN2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_P75OpBb0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1b2PTVlb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_BllF7PO7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YSQ9EFFC, 1, m, &cIf_YSQ9EFFC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_1JczFUTc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cBrshL0c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_cBrshL0c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_tZ8qJGyi_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_T76GZnGl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_85Ur08w0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_dnhppSAQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uJH3jpdw, 0, m, &cVar_uJH3jpdw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Mx47VzSq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_J9Q4nEZD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_dsxQfxuQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cA6zUkN2, HV_BINOP_ADD, 1, m, &cBinop_cA6zUkN2_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_BllF7PO7, HV_BINOP_GREATER_THAN, 0, m, &cBinop_BllF7PO7_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_1JczFUTc, HV_BINOP_EQ, 0, m, &cBinop_1JczFUTc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_NVB2qh9z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_k0wWDIsc_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_kbY4oBp2, 0, m, &cIf_kbY4oBp2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_kbY4oBp2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_kOOy12XK_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_DpBFk1iJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_7NOX8Laf_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_gQ92jUzW_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_pSbTELV1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_IyHOdyeF, HV_BINOP_POW, 0, m, &cBinop_IyHOdyeF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_IyHOdyeF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eOE9yaxP, 0, m, &cIf_eOE9yaxP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_WrYN1rKS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_Rbvuseea_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_58H0OjQo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DpBFk1iJ, 0, m, &cIf_DpBFk1iJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_MvNVnhdU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_v7s9t9xh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_v7s9t9xh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DpBFk1iJ, 1, m, &cIf_DpBFk1iJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gQ92jUzW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_WrYN1rKS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_7NOX8Laf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_eOE9yaxP, 0, m, &cIf_eOE9yaxP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Rbvuseea_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IyHOdyeF, HV_BINOP_POW, 1, m, &cBinop_IyHOdyeF_sendMessage);
  cMsg_pSbTELV1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_eOE9yaxP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_dykhsmge, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_k0wWDIsc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kbY4oBp2, 1, m, &cIf_kbY4oBp2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_kOOy12XK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_46GVFoaV, HV_BINOP_GREATER_THAN, 1, m, &cBinop_46GVFoaV_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_A0MniN55, HV_BINOP_EQ, 1, m, &cBinop_A0MniN55_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_fVVYfIyb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_9tNcOcJt, HV_BINOP_ADD, 0, m, &cBinop_9tNcOcJt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9tNcOcJt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MvNVnhdU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_58H0OjQo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_46GVFoaV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eOE9yaxP, 1, m, &cIf_eOE9yaxP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_A0MniN55_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZGDkV6qk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_ZGDkV6qk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_dykhsmge, m);
}

void Heavy_WSTD_FL3NGR::cCast_6a4uoYqO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NVB2qh9z, 0, m, &cVar_NVB2qh9z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_kLq57UHF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fVVYfIyb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_ar444wv2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9tNcOcJt, HV_BINOP_ADD, 1, m, &cBinop_9tNcOcJt_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_46GVFoaV, HV_BINOP_GREATER_THAN, 0, m, &cBinop_46GVFoaV_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_A0MniN55, HV_BINOP_EQ, 0, m, &cBinop_A0MniN55_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_DFZ7qldW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_rGPVjyHQ, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cSwitchcase_etOvZnET_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_X39Wn8iZ, 0, m, &cSlice_X39Wn8iZ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_S4W8fgFy_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_X39Wn8iZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_EZPmURPA_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_EZPmURPA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_D5tSHeSi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_EZPmURPA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_EZPmURPA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qLe4iSd0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_S4W8fgFy_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_BPvsPy7q, 0, m, &cSlice_BPvsPy7q_sendMessage);
      break;
    }
    default: {
      cSwitchcase_7oSjmJ9b_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_BPvsPy7q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_aC6O4D0X_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_aC6O4D0X_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_IuddAgUM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_aC6O4D0X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_aC6O4D0X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_cufhi6NL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_X7m6u78y_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_m0c26eU1, 0, m, &cSlice_m0c26eU1_sendMessage);
      break;
    }
    default: {
      cSwitchcase_TURO3ukY_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_m0c26eU1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_BMJQc7RT_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_BMJQc7RT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_zpAHh18r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_BMJQc7RT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_BMJQc7RT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_3xwlnTFE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_TURO3ukY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_rh2vxvXO, 0, m, &cSlice_rh2vxvXO_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_rh2vxvXO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_1k4lx7i3_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_1k4lx7i3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_XEsqA6A3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_1k4lx7i3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_1k4lx7i3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_PChKCR7d_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_uqp4v46B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3BcjWn4U, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_6nr56PiY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Ew6SYNmj, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_NA3j37Ns_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_g7ayiPgm, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_aLHk2RBD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_H9eeAmXw, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_FsWvIOzE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MKlYNoSv, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_iSFlWSHl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_XQ9DsUeg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_XQ9DsUeg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_y0wpXSxQ, HV_BINOP_DIVIDE, 1, m, &cBinop_y0wpXSxQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MWohHxK1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_FeGuVXMH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_ccCpiVbO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_o2634bEr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_FeGuVXMH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ccCpiVbO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_y0wpXSxQ, HV_BINOP_DIVIDE, 0, m, &cBinop_y0wpXSxQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_MWohHxK1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_o2634bEr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_y0wpXSxQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WyEBj3pe, HV_BINOP_MULTIPLY, 1, m, &cBinop_WyEBj3pe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_WyEBj3pe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fOjh1bzr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BlFlmSug_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_bU0PR63B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_H7H3yOwm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_YKDw4fyH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_IZLAAvNy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_CBODa6Nl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_El8UU8Yb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_El8UU8Yb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WyEBj3pe, HV_BINOP_MULTIPLY, 0, m, &cBinop_WyEBj3pe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_nGVQoNh1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_diAc9djb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_diAc9djb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hH0URykp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_8uzfXi45_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1gye7lH3, 1, m, &cVar_1gye7lH3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_1gye7lH3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_q2pWBA1B_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Z43dNeVq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oIha7pVK, HV_BINOP_MULTIPLY, 1, m, &cBinop_oIha7pVK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_DvW9WMRz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Z43dNeVq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_P7NjEfL2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_xcaDcygs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_xcaDcygs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HzgQxxlp, HV_BINOP_MULTIPLY, 1, m, &cBinop_HzgQxxlp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_AbE443IM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vOJSdYsM, HV_BINOP_MULTIPLY, 1, m, &cBinop_vOJSdYsM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_CC2V8Gw9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_AbE443IM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_6qBtrkkQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gG2Ei2fy, HV_BINOP_MULTIPLY, 1, m, &cBinop_gG2Ei2fy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_9XovuwE5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_jdTsMZQL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_jdTsMZQL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gbUkgEZk, HV_BINOP_MULTIPLY, 1, m, &cBinop_gbUkgEZk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_V4ABWl9u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UJQkurkC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_CBODa6Nl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_w19jQ6oj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_sp6rc319_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_nGVQoNh1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_fOjh1bzr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_bU0PR63B_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_BlFlmSug_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_YKDw4fyH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_H7H3yOwm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_1YMI8Ry6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_IZLAAvNy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_gYpqnUr5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_5qZGgFlA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_y0Ag82V1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_hH0URykp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_79BpcU52_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_79BpcU52_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kEcCk9Rq, HV_BINOP_MULTIPLY, 1, m, &cBinop_kEcCk9Rq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_kEcCk9Rq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_PekYQGKa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_PekYQGKa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_5qZGgFlA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_q2pWBA1B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_wutaCLoT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_wutaCLoT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4xRgcnwQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EP8d5wAy_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3o88FagO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nLqcnmh5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LUzo2lV9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MG5WkP3z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_oIha7pVK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uqp4v46B_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_HzgQxxlp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6nr56PiY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_vOJSdYsM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NA3j37Ns_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_gG2Ei2fy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aLHk2RBD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_gbUkgEZk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FsWvIOzE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_t8qAHIPU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sp6rc319, 1, m, &cVar_sp6rc319_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_rlW3CqqP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_V4ABWl9u, 0, m, &cVar_V4ABWl9u_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_MG5WkP3z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oIha7pVK, HV_BINOP_MULTIPLY, 0, m, &cBinop_oIha7pVK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_3o88FagO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gG2Ei2fy, HV_BINOP_MULTIPLY, 0, m, &cBinop_gG2Ei2fy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_LUzo2lV9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HzgQxxlp, HV_BINOP_MULTIPLY, 0, m, &cBinop_HzgQxxlp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_EP8d5wAy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gbUkgEZk, HV_BINOP_MULTIPLY, 0, m, &cBinop_gbUkgEZk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_nLqcnmh5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vOJSdYsM, HV_BINOP_MULTIPLY, 0, m, &cBinop_vOJSdYsM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_4xRgcnwQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_w19jQ6oj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1gye7lH3, 0, m, &cVar_1gye7lH3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_UJQkurkC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sp6rc319, 0, m, &cVar_sp6rc319_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_d3xDojOi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4SbpfdPS, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_VbYg9CFG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Y7i0X1u3, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_MmiiZzGF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BWuJnSTy, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_WYKkJdAp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3NGDH9nc, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_KjkjwPuH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_K0JHwPlz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_K0JHwPlz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jrzchlun, HV_BINOP_DIVIDE, 1, m, &cBinop_jrzchlun_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6lwc8Yjh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_ffErKCjx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_m9iarxYp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_QEY39gX1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_ffErKCjx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_m9iarxYp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jrzchlun, HV_BINOP_DIVIDE, 0, m, &cBinop_jrzchlun_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_6lwc8Yjh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QEY39gX1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_jrzchlun_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TIgUSh4y, HV_BINOP_MULTIPLY, 1, m, &cBinop_TIgUSh4y_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_TIgUSh4y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Dl6pdUOE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_elDVOrE6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_JoqNyRQd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_RqJYQlza_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_OgfPDZ6j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_X8xberFJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_oz5YDHaZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_DuJIy4Lw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_DuJIy4Lw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TIgUSh4y, HV_BINOP_MULTIPLY, 0, m, &cBinop_TIgUSh4y_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_mITRUu1s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_KCArCSsC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_KCArCSsC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_STh83mMx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Ph8ixbgW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_y1SVgDFp, HV_BINOP_MULTIPLY, 1, m, &cBinop_y1SVgDFp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_RNPRkyOy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dcSAAFTy, 1, m, &cVar_dcSAAFTy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_452fOwPF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aUXWSFhv, HV_BINOP_MULTIPLY, 1, m, &cBinop_aUXWSFhv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_PaYYyxki_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_MsQ8bOn9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_MsQ8bOn9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JcWds1z5, HV_BINOP_MULTIPLY, 1, m, &cBinop_JcWds1z5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_dcSAAFTy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aH0OQxRJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_SkdJY9ci_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_T5vgoVy6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_oz5YDHaZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LB7clPTe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_82821BI6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_mITRUu1s_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_elDVOrE6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_OgfPDZ6j_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Dl6pdUOE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_JoqNyRQd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_RqJYQlza_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_fgJIGKM7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_X8xberFJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_fFJag43t_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_VhOwvRiy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_hPLvPMer_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_STh83mMx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_1bgiLrJN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_1bgiLrJN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VlvsT3E5, HV_BINOP_MULTIPLY, 1, m, &cBinop_VlvsT3E5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_VlvsT3E5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_zGX0EDlK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_zGX0EDlK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_VhOwvRiy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_aH0OQxRJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_YbnYfQ6u_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_YbnYfQ6u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TubJ97LY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DcExFkc4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mWfrsDEw_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vFmUDM2w_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_TZjzXUhV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_d3xDojOi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_y1SVgDFp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VbYg9CFG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_aUXWSFhv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MmiiZzGF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_JcWds1z5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WYKkJdAp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_d7ZKXTBN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_82821BI6, 1, m, &cVar_82821BI6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_W8T7vpBx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SkdJY9ci, 0, m, &cVar_SkdJY9ci_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_T5vgoVy6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_82821BI6, 0, m, &cVar_82821BI6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_LB7clPTe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dcSAAFTy, 0, m, &cVar_dcSAAFTy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_mWfrsDEw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_y1SVgDFp, HV_BINOP_MULTIPLY, 0, m, &cBinop_y1SVgDFp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_DcExFkc4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aUXWSFhv, HV_BINOP_MULTIPLY, 0, m, &cBinop_aUXWSFhv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_vFmUDM2w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TZjzXUhV, HV_BINOP_MULTIPLY, 0, m, &cBinop_TZjzXUhV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_TubJ97LY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JcWds1z5, HV_BINOP_MULTIPLY, 0, m, &cBinop_JcWds1z5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_0WN6YffP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lzNGt3BA, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_8ox8f1n1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XTM74WSO, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_OLoHrz8c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ok0C4HoQ, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_YQfA70O8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mdCI1r9J, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_V5OfEkcs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PiO2EgoH, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_Shj50vxq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_9ClgqaYz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_9ClgqaYz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_X1DxxJON, HV_BINOP_DIVIDE, 1, m, &cBinop_X1DxxJON_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vu3UWCys_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_NbSZGVZA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_NOkSqsfK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_yfNqh358_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_NbSZGVZA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_NOkSqsfK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_X1DxxJON, HV_BINOP_DIVIDE, 0, m, &cBinop_X1DxxJON_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_vu3UWCys_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yfNqh358_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_X1DxxJON_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ThNv1u6p, HV_BINOP_MULTIPLY, 1, m, &cBinop_ThNv1u6p_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ThNv1u6p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DATloxJC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eSldoO8u_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_qwDW0NJo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hIZExSPH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_OI1xOZyE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_mlurtYiw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_XGP9icf7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_tWacZqur_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_tWacZqur_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ThNv1u6p, HV_BINOP_MULTIPLY, 0, m, &cBinop_ThNv1u6p_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_SRjykUiw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_facjvzwf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_facjvzwf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gVDyKJ8Z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_m8GgDkhd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TlJGu5s5, HV_BINOP_MULTIPLY, 1, m, &cBinop_TlJGu5s5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_ArpFSJBF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_39P9TWpf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_39P9TWpf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_m8GgDkhd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Bqr7FKJ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_st4Gv6Nh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_st4Gv6Nh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rQXlnmqP, HV_BINOP_MULTIPLY, 1, m, &cBinop_rQXlnmqP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_nuSHHTP5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gAw19p1C, HV_BINOP_MULTIPLY, 1, m, &cBinop_gAw19p1C_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_cuKreM0V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_NAldP2ZK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_NAldP2ZK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_nuSHHTP5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_KEBZRgIf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_W8htIcMm, 1, m, &cVar_W8htIcMm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_VrNmnjvD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_P46G9i7J, HV_BINOP_MULTIPLY, 1, m, &cBinop_P46G9i7J_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_ekyVBvAC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_z5cWpuNv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_z5cWpuNv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fS8R4h4e, HV_BINOP_MULTIPLY, 1, m, &cBinop_fS8R4h4e_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_W8htIcMm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ir9KbW4p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_VNE6V6kb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_j0wZ4Sik_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_XGP9icf7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4ZjvsMWD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_nZKePTKl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_SRjykUiw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_DATloxJC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_qwDW0NJo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_eSldoO8u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_OI1xOZyE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_hIZExSPH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_GWJXzfeF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_mlurtYiw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Lq7Coeq1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_DpYX9iUJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_R4cruUEO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_gVDyKJ8Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_1GDemIOh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_1GDemIOh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LwzrzpXc, HV_BINOP_MULTIPLY, 1, m, &cBinop_LwzrzpXc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_LwzrzpXc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_9zSXkHvI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9zSXkHvI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_DpYX9iUJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_Ir9KbW4p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_4lJsL5Gc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_4lJsL5Gc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7v33CL8X_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yZWcQ5FB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eO1EGvsN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Rb0fcWXl_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_D8OkbTCj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3E7OQPyz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_TlJGu5s5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0WN6YffP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_rQXlnmqP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8ox8f1n1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_gAw19p1C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OLoHrz8c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_P46G9i7J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YQfA70O8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_fS8R4h4e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_V5OfEkcs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_tJGNum8q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VNE6V6kb, 0, m, &cVar_VNE6V6kb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_GhZyC1ZN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nZKePTKl, 1, m, &cVar_nZKePTKl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_3E7OQPyz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TlJGu5s5, HV_BINOP_MULTIPLY, 0, m, &cBinop_TlJGu5s5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_eO1EGvsN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_P46G9i7J, HV_BINOP_MULTIPLY, 0, m, &cBinop_P46G9i7J_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_D8OkbTCj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rQXlnmqP, HV_BINOP_MULTIPLY, 0, m, &cBinop_rQXlnmqP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_yZWcQ5FB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fS8R4h4e, HV_BINOP_MULTIPLY, 0, m, &cBinop_fS8R4h4e_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Rb0fcWXl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gAw19p1C, HV_BINOP_MULTIPLY, 0, m, &cBinop_gAw19p1C_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_7v33CL8X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_4ZjvsMWD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_W8htIcMm, 0, m, &cVar_W8htIcMm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_j0wZ4Sik_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nZKePTKl, 0, m, &cVar_nZKePTKl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_tZ8qJGyi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DFZ7qldW, 1, m, &cIf_DFZ7qldW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_KzU5JcC6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_rGPVjyHQ, m);
}

void Heavy_WSTD_FL3NGR::cBinop_T76GZnGl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KzU5JcC6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_85Ur08w0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DFZ7qldW, 0, m, &cIf_DFZ7qldW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_6tBSl4YM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_E0qh3bxh, HV_BINOP_DIVIDE, 0, m, &cBinop_E0qh3bxh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_sojaGYME_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Y58LRnKh, HV_BINOP_DIVIDE, 1, m, &cBinop_Y58LRnKh_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_E0qh3bxh, HV_BINOP_DIVIDE, 1, m, &cBinop_E0qh3bxh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_wj1Ygto6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YexD18JJ, HV_BINOP_DIVIDE, 0, m, &cBinop_YexD18JJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_zf19vY49_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YexD18JJ, HV_BINOP_DIVIDE, 1, m, &cBinop_YexD18JJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_civB8mzX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Y58LRnKh, HV_BINOP_DIVIDE, 0, m, &cBinop_Y58LRnKh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_0pNsNheM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6tBSl4YM, 0, m, &cVar_6tBSl4YM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_DlY5oWBA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sojaGYME, 0, m, &cVar_sojaGYME_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Y58LRnKh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_wj1Ygto6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_E0qh3bxh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_zf19vY49_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_YexD18JJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_AscqUqFP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_cPgkIzrr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_vweUxhpO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_pvvGD9IT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_chg9G7ob_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_AscqUqFP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_pvvGD9IT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_chg9G7ob_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_cPgkIzrr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_vweUxhpO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LXBN9OL4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_jM2guV0z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_R9T2Ze0Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_EgAOI3MD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_i3ush9I5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_SNy4gAMW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fua1QsJy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_2yc68acT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_C30QwcnN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_mlK4c5f2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gHSW8rpo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_96KIEGzE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AcMQwNnk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_ZlRhaVem_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OsIsr4zX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_quzCnWZC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Aiq8sSUt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_vAbtBSvo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7Y1KL0QQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_wI7SaFpj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZNVb2m4O_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_R710PoNs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QXO7wNV4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_COrBuNuK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oEv5rBUn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_cKDxG0YX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_MkHkGS1E_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_MkHkGS1E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_y3pWWMry, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_9CwOr6yd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_WmZ27RmH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_WmZ27RmH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_UJVnSdhb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_Kb0Ni9zK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MzZmYZVy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_JxM29j03_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_l6p0NutL_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_FzNRzPa6, m);
}

void Heavy_WSTD_FL3NGR::cBinop_UJVnSdhb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_TLDNkXzt, m);
}

void Heavy_WSTD_FL3NGR::cMsg_MzZmYZVy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_JxM29j03_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_l6p0NutL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_hBXmsBJy, m);
}

void Heavy_WSTD_FL3NGR::cMsg_hjbEBTSP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_JPVXBQ7N_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_JPVXBQ7N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_JENyFaiQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_qCb3MdoT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_O3C5Mjm2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_HjSBUy8H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_FFnOZfsB_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_wtBPylsH, m);
}

void Heavy_WSTD_FL3NGR::cBinop_JENyFaiQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_gVqyuPUw, m);
}

void Heavy_WSTD_FL3NGR::cMsg_O3C5Mjm2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_HjSBUy8H_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_FFnOZfsB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_OTz5TTiU, m);
}

void Heavy_WSTD_FL3NGR::cBinop_zYoIRRTH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_MRFIBaeb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_MRFIBaeb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_joNgmVGo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_BbZAp2zM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HO6s7RvS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_gsvaJuXK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xnmrUeNo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_joNgmVGo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_l0nvN8P7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_l0nvN8P7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_e8uIcekz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_V9iIpC20_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_V9iIpC20_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zgMVtHr7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_e8uIcekz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_052lWoe7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_052lWoe7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_0Y6cQWrQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_zgMVtHr7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ZPyO7Otw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ZPyO7Otw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_fT80meIR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0Y6cQWrQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_BbZAp2zM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_fT80meIR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_gsvaJuXK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_POK2YRng_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_00KzFWNF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_00KzFWNF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OOcZsaGa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_ALuvC7JG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_y7XccwvN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_y7XccwvN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_rTYbeMvq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_aIQQshRH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_aIQQshRH, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_7CGrocz0, 0, m, &cDelay_7CGrocz0_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_aIQQshRH, 0, m, &cDelay_aIQQshRH_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_UGbqCpQu, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_7CGrocz0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_7CGrocz0, m);
  cMsg_b5uJ9qTH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_aiXcnSDW_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_eSD1UEAr_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_ginW1tWi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_II9Oa664_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_3dL54QM2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MZkNsFNq_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_aIQQshRH, 2, m, &cDelay_aIQQshRH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_b210waGr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_II9Oa664_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_3dL54QM2, 0, m, &hTable_3dL54QM2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_rTYbeMvq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_ginW1tWi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_b5uJ9qTH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_3dL54QM2, 0, m, &hTable_3dL54QM2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_b210waGr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_aIQQshRH, 0, m, &cDelay_aIQQshRH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_MZkNsFNq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_7CGrocz0, 2, m, &cDelay_7CGrocz0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_eSD1UEAr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_UGbqCpQu, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_zBBocC1v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_s6lp4T8x_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_s6lp4T8x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_2eO5xTKh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_xJHL47Rm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xJHL47Rm, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_HgoMIafE, 0, m, &cDelay_HgoMIafE_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_xJHL47Rm, 0, m, &cDelay_xJHL47Rm_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_QEAJ4geC, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_HgoMIafE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_HgoMIafE, m);
  cMsg_opxTqF62_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_jExzXfPt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_Oi4pb6XD_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_oHzD1502_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mOwNW8ly_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_9htYfx5P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CBfMQV1i_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_xJHL47Rm, 2, m, &cDelay_xJHL47Rm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sl1wFRha_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_mOwNW8ly_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_9htYfx5P, 0, m, &hTable_9htYfx5P_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_2eO5xTKh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_oHzD1502_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_opxTqF62_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_9htYfx5P, 0, m, &hTable_9htYfx5P_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_sl1wFRha_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_xJHL47Rm, 0, m, &cDelay_xJHL47Rm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_CBfMQV1i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_HgoMIafE, 2, m, &cDelay_HgoMIafE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Oi4pb6XD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_QEAJ4geC, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cVar_TvHqzfoc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rcI0aHfR, HV_BINOP_MULTIPLY, 0, m, &cBinop_rcI0aHfR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_q6zxyCjn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_lCebOOYL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_lCebOOYL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1qQYaOUJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_rcI0aHfR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_iMvC1bpO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_yJHKgtsp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rcI0aHfR, HV_BINOP_MULTIPLY, 1, m, &cBinop_rcI0aHfR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_1qQYaOUJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_yJHKgtsp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_iMvC1bpO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_lCCsWbjT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_lCCsWbjT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Q5vIyBhG_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_0U5u95Cz, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Q5vIyBhG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_c6CGK9o7, m);
}

void Heavy_WSTD_FL3NGR::cVar_2Hhje5VL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WV2BqaLT, HV_BINOP_MULTIPLY, 0, m, &cBinop_WV2BqaLT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_B0cH8jWP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_QWVtG4Ne_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_QWVtG4Ne_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8M8VvdZf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_WV2BqaLT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_1ApBHd4J_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_tqF1k0KA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WV2BqaLT, HV_BINOP_MULTIPLY, 1, m, &cBinop_WV2BqaLT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_8M8VvdZf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_tqF1k0KA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_1ApBHd4J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_GOuTfcf0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_GOuTfcf0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_0rRTXe30_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_eejh9GHF, m);
}

void Heavy_WSTD_FL3NGR::cBinop_0rRTXe30_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Qt0A8i22, m);
}

void Heavy_WSTD_FL3NGR::cMsg_OOcZsaGa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XH1YjBX4, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cUnop_qJ8n9AFN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_YY8u5DGB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_9txntiFL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_XEogDE0w_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_TqsFipP1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_qJ8n9AFN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_G40DWKLS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_ZcZCR7lY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ZcZCR7lY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5FkV8POZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_5FkV8POZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_XEogDE0w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_G40DWKLS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5FkV8POZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FmoId4X3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_YY8u5DGB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5FkV8POZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_5FkV8POZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_FmoId4X3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7lTxxPuX, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_Zqe9HGtl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_qA2c3ktA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qA2c3ktA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9txntiFL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TqsFipP1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_eXXMC9ha_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_LXcGdTkb, 0, m, &cSlice_LXcGdTkb_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Wk9uryRp_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_LXcGdTkb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_CbFrbLV9_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_CbFrbLV9_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_uTG9mwC1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_CbFrbLV9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_CbFrbLV9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_aSQUXB0X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_Wk9uryRp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_fBguEFAl, 0, m, &cSlice_fBguEFAl_sendMessage);
      break;
    }
    default: {
      cSwitchcase_5YKeYser_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_fBguEFAl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_IuvFcoB7_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_IuvFcoB7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_M1TVNkcR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_IuvFcoB7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_IuvFcoB7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_DuHLNSnR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_5YKeYser_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_eSos4r8M, 0, m, &cSlice_eSos4r8M_sendMessage);
      break;
    }
    default: {
      cSwitchcase_gRl8ZU5p_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_eSos4r8M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_SdgN4wN8_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_SdgN4wN8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_Hwby63Uh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_SdgN4wN8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_SdgN4wN8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_fPXIKBaG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_gRl8ZU5p_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_AS15WsvD, 0, m, &cSlice_AS15WsvD_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_AS15WsvD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_FML0hOJ1_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_FML0hOJ1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_UAETENPN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_FML0hOJ1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_FML0hOJ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Mn9BiI2z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_HO6s7RvS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_n95iWa1G, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_xnmrUeNo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mOw1kwCd, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_066e1n8y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_g3cGZfHM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_g3cGZfHM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_A0zp7kID, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_wRz9D0OU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_zhzarLNk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_zhzarLNk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_vAzJvvBR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_uYEr6xUh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_US0nIZ3V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_P0pCEM6K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_L7qm35jm_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_LlRku39s, m);
}

void Heavy_WSTD_FL3NGR::cBinop_vAzJvvBR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_rYNkRQIl, m);
}

void Heavy_WSTD_FL3NGR::cMsg_US0nIZ3V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_P0pCEM6K_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_L7qm35jm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_l9TUCfS0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_PuGy9jUY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_1iJu90Bo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_1iJu90Bo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_BlfZ1KIT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_xKuXDpCU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BvWiT1cO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_YOp08IJa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_44ElEixM_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_2p7296fN, m);
}

void Heavy_WSTD_FL3NGR::cBinop_BlfZ1KIT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_uICnLuHu, m);
}

void Heavy_WSTD_FL3NGR::cMsg_BvWiT1cO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_YOp08IJa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_44ElEixM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_b5hegUeA, m);
}

void Heavy_WSTD_FL3NGR::cBinop_wB7ODXO4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_oe8QNqmE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_oe8QNqmE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_cuID1Hs1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_vnkgTsS3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aT2kDVr0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_U1npJFQD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uSoLv1uD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_cuID1Hs1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_1ydYpefb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_1ydYpefb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IHfbH1BA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OTUMn1aP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_OTUMn1aP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DJwO2rCT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_IHfbH1BA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_eHMMRry7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_eHMMRry7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_sKQPUZrW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_DJwO2rCT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_THZEUcYz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_THZEUcYz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_2Cj3dMAm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_sKQPUZrW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_vnkgTsS3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_2Cj3dMAm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_U1npJFQD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_QUfmqkqA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_14SNTeTh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_14SNTeTh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5bGQdJJq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_Ibqb3JUG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_rl7d469I_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_rl7d469I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_bKsWKhU8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_IAHkcw2b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_IAHkcw2b, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_OFmXlRco, 0, m, &cDelay_OFmXlRco_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_IAHkcw2b, 0, m, &cDelay_IAHkcw2b_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_scy2FQ2c, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_OFmXlRco_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_OFmXlRco, m);
  cMsg_ZiOs1sZQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_A4dZVFuB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_nPo3Nwp7_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_gS9ImiTz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_d9N8XwYJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_4mO83VX8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VwaMkGNa_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_IAHkcw2b, 2, m, &cDelay_IAHkcw2b_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_03DA7liU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_d9N8XwYJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_4mO83VX8, 0, m, &hTable_4mO83VX8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_bKsWKhU8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_gS9ImiTz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_ZiOs1sZQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_4mO83VX8, 0, m, &hTable_4mO83VX8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_03DA7liU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_IAHkcw2b, 0, m, &cDelay_IAHkcw2b_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_VwaMkGNa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_OFmXlRco, 2, m, &cDelay_OFmXlRco_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_nPo3Nwp7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_scy2FQ2c, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_V3fQPMCn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_YFrhPxyf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_YFrhPxyf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_lase8drn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_z0om9l53_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_z0om9l53, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_EgBGY2oD, 0, m, &cDelay_EgBGY2oD_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_z0om9l53, 0, m, &cDelay_z0om9l53_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_iCvHHwZP, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_EgBGY2oD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_EgBGY2oD, m);
  cMsg_WAQT0Ge1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_2cWMp7vM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_zXrWWGJe_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_bfMsKKJw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_w4C5TUMx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_rsLnTmTc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Msx9D4pE_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_z0om9l53, 2, m, &cDelay_z0om9l53_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_x22zOhOp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_w4C5TUMx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_rsLnTmTc, 0, m, &hTable_rsLnTmTc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_lase8drn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_bfMsKKJw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_WAQT0Ge1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_rsLnTmTc, 0, m, &hTable_rsLnTmTc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_x22zOhOp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_z0om9l53, 0, m, &cDelay_z0om9l53_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Msx9D4pE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_EgBGY2oD, 2, m, &cDelay_EgBGY2oD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_zXrWWGJe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_iCvHHwZP, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cVar_LKWNK3iH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sb0Im6y8, HV_BINOP_MULTIPLY, 0, m, &cBinop_sb0Im6y8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_3TZVDKTc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_5iI1hxfA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_5iI1hxfA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_168PXHl1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_sb0Im6y8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_q3CDpU3A_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_i0QKemou_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sb0Im6y8, HV_BINOP_MULTIPLY, 1, m, &cBinop_sb0Im6y8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_168PXHl1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_i0QKemou_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_q3CDpU3A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_MF72kI8M_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_MF72kI8M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Ul6tbY97_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_RdY48TDT, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Ul6tbY97_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_0MPkzyKO, m);
}

void Heavy_WSTD_FL3NGR::cVar_H8AluwqR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KXIDPjmA, HV_BINOP_MULTIPLY, 0, m, &cBinop_KXIDPjmA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_E2NCrGDz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_MjHnD1tU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_MjHnD1tU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nDMvjx3t_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_KXIDPjmA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_YWwacsBk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_LHetqGfD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KXIDPjmA, HV_BINOP_MULTIPLY, 1, m, &cBinop_KXIDPjmA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_nDMvjx3t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_LHetqGfD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_YWwacsBk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Miv9JINh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Miv9JINh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_FWdxZ2q4_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_neGDFWv3, m);
}

void Heavy_WSTD_FL3NGR::cBinop_FWdxZ2q4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Pcy1dl4X, m);
}

void Heavy_WSTD_FL3NGR::cMsg_5bGQdJJq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kWehlBE9, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cUnop_w2Oka9zK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_fgHpD9nH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_DZs7rCua_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_pG6Xll52_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_rWCZ9W75_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_w2Oka9zK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_8kXVu0rB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_gwurYEXm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gwurYEXm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aiH7zy8B, HV_BINOP_MULTIPLY, 1, m, &cBinop_aiH7zy8B_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_pG6Xll52_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_8kXVu0rB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_aiH7zy8B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7WyCa9zn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_fgHpD9nH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aiH7zy8B, HV_BINOP_MULTIPLY, 0, m, &cBinop_aiH7zy8B_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_7WyCa9zn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_AD6NOWBN, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_ZIKTQvTw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_EsoqVPVS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_EsoqVPVS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DZs7rCua_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rWCZ9W75_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_Ejn05I40_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_HbX7Rult, 0, m, &cSlice_HbX7Rult_sendMessage);
      break;
    }
    default: {
      cSwitchcase_25Xw5s4b_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_HbX7Rult_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_cZ4htEdF_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_cZ4htEdF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_tl94wXNj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_cZ4htEdF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_cZ4htEdF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ydV5PWVu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_25Xw5s4b_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_KLb2IysI, 0, m, &cSlice_KLb2IysI_sendMessage);
      break;
    }
    default: {
      cSwitchcase_doVsY8eF_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_KLb2IysI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_JFSdyf4B_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_JFSdyf4B_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_Kkch5TV6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_JFSdyf4B_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_JFSdyf4B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_dO9arZNb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_doVsY8eF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_tlj1gLuJ, 0, m, &cSlice_tlj1gLuJ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_VIVcy9V6_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_tlj1gLuJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_icv2KEOv_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_icv2KEOv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_ZeaSYo0A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_icv2KEOv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_icv2KEOv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_zzgHUNL0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_VIVcy9V6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_7W4yCwpp, 0, m, &cSlice_7W4yCwpp_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_7W4yCwpp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_V7c8snYy_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_V7c8snYy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_zCZLRCnr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_V7c8snYy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_V7c8snYy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Uc2g3iSq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_aT2kDVr0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WYDF5Jh2, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_uSoLv1uD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WUTeUERH, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_uaUfOjM1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_lKTED1q3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_lKTED1q3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_gDVwjPQv, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_Sylzi5aC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_KX5mflSP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_KX5mflSP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_i6zSjDM7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_Vq2UwYeb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_apwF2jMu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_LMfuGvAo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_ym9oDXeT_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_h6rZl739, m);
}

void Heavy_WSTD_FL3NGR::cBinop_i6zSjDM7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_yAN3DImb, m);
}

void Heavy_WSTD_FL3NGR::cMsg_apwF2jMu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_LMfuGvAo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ym9oDXeT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_y51AZSzI, m);
}

void Heavy_WSTD_FL3NGR::cMsg_OqlN4PjH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_cKk9leOx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_cKk9leOx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_aXQeArl1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_g3sRcTjp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oD3PIrZI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_3hsRpICi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_McUXAHsu_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_LUnfpqnN, m);
}

void Heavy_WSTD_FL3NGR::cBinop_aXQeArl1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_fJlfZtxT, m);
}

void Heavy_WSTD_FL3NGR::cMsg_oD3PIrZI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_3hsRpICi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_McUXAHsu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_hLYhbnsF, m);
}

void Heavy_WSTD_FL3NGR::cBinop_w6k2ZTvi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Ypw4HUiB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Ypw4HUiB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_LnqWy9ns_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_0V5HsOpe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_j3xlMHj4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_f66NlDhT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5b4q9tZN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_LnqWy9ns_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_K5pOgMGt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_K5pOgMGt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BS7aE26v_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cCTVbREi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_BS7aE26v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_cFD1Prv2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_cCTVbREi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Cd2hOxNy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_cFD1Prv2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_0DEpwmyU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Cd2hOxNy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_dAaVme1e_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_dAaVme1e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_lXX0Zt7m_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0DEpwmyU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_0V5HsOpe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_lXX0Zt7m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_f66NlDhT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Qs2G3Rdq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_M3e1dZGa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_M3e1dZGa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gwdKQdsp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_gPrJ1Tkw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_UdUl5bhR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_UdUl5bhR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_CuPQAsao_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_aAD1Dg5N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_aAD1Dg5N, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_gxzh1X3B, 0, m, &cDelay_gxzh1X3B_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_aAD1Dg5N, 0, m, &cDelay_aAD1Dg5N_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_C4GeiriC, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_gxzh1X3B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_gxzh1X3B, m);
  cMsg_15Q4X9Wd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_o9uYKCvB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_fBT0dUQc_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_lJcYmdDL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3hwK52wF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_SXSxbArH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qUSnau64_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_aAD1Dg5N, 2, m, &cDelay_aAD1Dg5N_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_54vVyqTm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_3hwK52wF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_SXSxbArH, 0, m, &hTable_SXSxbArH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_CuPQAsao_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_lJcYmdDL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_15Q4X9Wd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_SXSxbArH, 0, m, &hTable_SXSxbArH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_54vVyqTm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_aAD1Dg5N, 0, m, &cDelay_aAD1Dg5N_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_qUSnau64_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_gxzh1X3B, 2, m, &cDelay_gxzh1X3B_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_fBT0dUQc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_C4GeiriC, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_iBmr3LFI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_W2dTqLDP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_W2dTqLDP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_LpvMmULo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_DdS4t9qx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_DdS4t9qx, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_cYgOquOR, 0, m, &cDelay_cYgOquOR_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_DdS4t9qx, 0, m, &cDelay_DdS4t9qx_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_vAGiRPVF, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_cYgOquOR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_cYgOquOR, m);
  cMsg_mLuJf6nN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_vn3jG7fJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_E9H17F5L_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_WUWibqdR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZNB8lRWI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_P0hGe6xa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lcLAAfZg_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_DdS4t9qx, 2, m, &cDelay_DdS4t9qx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_id3xFrkC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_ZNB8lRWI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_P0hGe6xa, 0, m, &hTable_P0hGe6xa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_LpvMmULo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_WUWibqdR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_mLuJf6nN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_P0hGe6xa, 0, m, &hTable_P0hGe6xa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_id3xFrkC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_DdS4t9qx, 0, m, &cDelay_DdS4t9qx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_lcLAAfZg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_cYgOquOR, 2, m, &cDelay_cYgOquOR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_E9H17F5L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_vAGiRPVF, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cVar_PEeEoTRV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2j703k2a, HV_BINOP_MULTIPLY, 0, m, &cBinop_2j703k2a_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_IlwV4gon_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_KgmVeNVL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_KgmVeNVL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JjLAlrrt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_2j703k2a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Jt9RWV5s_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_tZvhHU59_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2j703k2a, HV_BINOP_MULTIPLY, 1, m, &cBinop_2j703k2a_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_JjLAlrrt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_tZvhHU59_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Jt9RWV5s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_gtEwBWXT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gtEwBWXT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_mxvcuqgJ_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Ry6ZqjKU, m);
}

void Heavy_WSTD_FL3NGR::cBinop_mxvcuqgJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_fzlq2bHd, m);
}

void Heavy_WSTD_FL3NGR::cVar_GxjBsKeQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UZVGln91, HV_BINOP_MULTIPLY, 0, m, &cBinop_UZVGln91_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_w5hQLNmA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_9JKOA8Wq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_9JKOA8Wq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_znCUfM5S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_UZVGln91_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_7qpXEGwd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_G3mo6gfl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UZVGln91, HV_BINOP_MULTIPLY, 1, m, &cBinop_UZVGln91_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_znCUfM5S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_G3mo6gfl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_7qpXEGwd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_tKy9spne_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_tKy9spne_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Qykbve15_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_iu7zgJ13, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Qykbve15_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_jzmkHT9k, m);
}

void Heavy_WSTD_FL3NGR::cMsg_gwdKQdsp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uVEHIEzW, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cUnop_JRlbxti5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_evppDnka_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_HxakLmgC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_JRlbxti5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_3jx3Br2v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_sits9kbR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_FXKdvS3t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_KO5R0ERG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_KO5R0ERG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rCp0aTKB, HV_BINOP_MULTIPLY, 1, m, &cBinop_rCp0aTKB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_sits9kbR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_FXKdvS3t_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_rCp0aTKB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hhC6tuH9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_evppDnka_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rCp0aTKB, HV_BINOP_MULTIPLY, 0, m, &cBinop_rCp0aTKB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_hhC6tuH9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NKY5izPI, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_teopDrxg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_lfY6hIBO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_lfY6hIBO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3jx3Br2v_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HxakLmgC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_x2cPDdX4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_82NJIwge, 0, m, &cSlice_82NJIwge_sendMessage);
      break;
    }
    default: {
      cSwitchcase_rryQSjnn_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_82NJIwge_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_FUM1DqxN_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_FUM1DqxN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_cq1esJeH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_FUM1DqxN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_FUM1DqxN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_IIiKrnLe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_rryQSjnn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_gXc15SE9, 0, m, &cSlice_gXc15SE9_sendMessage);
      break;
    }
    default: {
      cSwitchcase_UCVdWzaM_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_gXc15SE9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_dZHaPjKB_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_dZHaPjKB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_ZKRObMeT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_dZHaPjKB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_dZHaPjKB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_pJhxmfLo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_UCVdWzaM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_wsWW3Mmj, 0, m, &cSlice_wsWW3Mmj_sendMessage);
      break;
    }
    default: {
      cSwitchcase_guJ0RMrE_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_wsWW3Mmj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_nDQHa9Qd_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_nDQHa9Qd_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_e2M7ElJd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_nDQHa9Qd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_nDQHa9Qd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_mhpqg7uO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_guJ0RMrE_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_dVIU4wlx, 0, m, &cSlice_dVIU4wlx_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_dVIU4wlx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_9K5lNm01_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_9K5lNm01_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_WHafkyuK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_9K5lNm01_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_9K5lNm01_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_IJeuRxRH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_j3xlMHj4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FmeKWVor, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_5b4q9tZN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iAymR6PP, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_Y8Nn1awi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_yVgsnzJi_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_etOvZnET_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_qroFs8bR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_yVgsnzJi_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_etOvZnET_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_u5zv1voK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_yVgsnzJi_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_etOvZnET_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_sF4EzBq7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_yVgsnzJi_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_etOvZnET_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_LXBN9OL4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_yVgsnzJi_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_etOvZnET_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_XLdBdUNL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_GugVWXAJ, 0, m, &cVar_GugVWXAJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_1eaWK3nN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_yoVWPTJx, 0, m, &cVar_yoVWPTJx_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_vTEJvdDw, 0, m, &cVar_vTEJvdDw_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_DSVCDksn, 0, m, &cVar_DSVCDksn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_C30QwcnN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_eXXMC9ha_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_R9T2Ze0Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_eXXMC9ha_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_i3ush9I5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_eXXMC9ha_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_fua1QsJy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_eXXMC9ha_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_sPUu7Bp6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2yc68acT, 0, m, &cVar_2yc68acT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ZYIrfRZw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jM2guV0z, 0, m, &cVar_jM2guV0z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_zVQ8Hsq6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SNy4gAMW, 0, m, &cVar_SNy4gAMW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Aiq8sSUt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_Ejn05I40_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_gHSW8rpo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_Ejn05I40_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_AcMQwNnk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_Ejn05I40_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_OsIsr4zX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_Ejn05I40_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_yTMzL9K2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_quzCnWZC, 0, m, &cVar_quzCnWZC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_z24QBIWP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mlK4c5f2, 0, m, &cVar_mlK4c5f2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_6r6wOwCv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZlRhaVem, 0, m, &cVar_ZlRhaVem_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_oEv5rBUn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_x2cPDdX4_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_7Y1KL0QQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_x2cPDdX4_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_ZNVb2m4O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_x2cPDdX4_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_QXO7wNV4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_x2cPDdX4_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_uF2ntFlN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_COrBuNuK, 0, m, &cVar_COrBuNuK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_q2MDMfKe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vAbtBSvo, 0, m, &cVar_vAbtBSvo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_En2hQ15v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_R710PoNs, 0, m, &cVar_R710PoNs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_5EJwOSEv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yoVWPTJx, 0, m, &cVar_yoVWPTJx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Vx2Hnu5p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vTEJvdDw, 0, m, &cVar_vTEJvdDw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_lHzQsKQp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DSVCDksn, 0, m, &cVar_DSVCDksn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_WUbKR1mq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gxErFJL6, 0, m, &cVar_gxErFJL6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_uWs5Z8ZH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_103Txfqo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gc2GDBNQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Cwkgepyw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Men2NoAt_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KXW3kBdp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fQfT6cKh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_R0ihYpZ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hnrtTii9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MuMrgJ3Q_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IKGI68xv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_LgRTMi5G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mAF92Ikx_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_B3jwyw4G_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DH4GC7AQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_iEZepmqQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_q8KYuGZK_sendMessage(_c, 0, m);
  cMsg_GapA106H_sendMessage(_c, 0, m);
  cMsg_pBzt9iEd_sendMessage(_c, 0, m);
  cMsg_iSFlWSHl_sendMessage(_c, 0, m);
  cMsg_KjkjwPuH_sendMessage(_c, 0, m);
  cMsg_Shj50vxq_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_QNPB1AO9, 0, m, &cVar_QNPB1AO9_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_gxErFJL6, 0, m, &cVar_gxErFJL6_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_VCFrLnMg, 0, m, &cVar_VCFrLnMg_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_V4ABWl9u, 0, m, &cVar_V4ABWl9u_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_SkdJY9ci, 0, m, &cVar_SkdJY9ci_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_VNE6V6kb, 0, m, &cVar_VNE6V6kb_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_clJmT6Nq, 0, m, &cVar_clJmT6Nq_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_AdIgIaX1, 0, m, &cVar_AdIgIaX1_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_1lKan4ib, 0, m, &cVar_1lKan4ib_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_WKqpXfaR, 0, m, &cVar_WKqpXfaR_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_CzCUVwT1, 0, m, &cVar_CzCUVwT1_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_OUWuvFRo, 0, m, &cVar_OUWuvFRo_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_xltjn71p, 0, m, &cVar_xltjn71p_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_FZJOOl6O, 0, m, &cVar_FZJOOl6O_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_NCnUVkFf, 0, m, &cVar_NCnUVkFf_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Lv8bLzZK, 0, m, &cVar_Lv8bLzZK_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_uJH3jpdw, 0, m, &cVar_uJH3jpdw_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_NVB2qh9z, 0, m, &cVar_NVB2qh9z_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_D5tSHeSi, 0, m, &cVar_D5tSHeSi_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_IuddAgUM, 0, m, &cVar_IuddAgUM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_zpAHh18r, 0, m, &cVar_zpAHh18r_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_XEsqA6A3, 0, m, &cVar_XEsqA6A3_sendMessage);
  cMsg_q6zxyCjn_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_TvHqzfoc, 0, m, &cVar_TvHqzfoc_sendMessage);
  cMsg_B0cH8jWP_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_2Hhje5VL, 0, m, &cVar_2Hhje5VL_sendMessage);
  cMsg_3TZVDKTc_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_LKWNK3iH, 0, m, &cVar_LKWNK3iH_sendMessage);
  cMsg_E2NCrGDz_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_H8AluwqR, 0, m, &cVar_H8AluwqR_sendMessage);
  cMsg_IlwV4gon_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_PEeEoTRV, 0, m, &cVar_PEeEoTRV_sendMessage);
  cMsg_w5hQLNmA_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_GxjBsKeQ, 0, m, &cVar_GxjBsKeQ_sendMessage);
  cMsg_ALuvC7JG_sendMessage(_c, 0, m);
  cMsg_zBBocC1v_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_uTG9mwC1, 0, m, &cVar_uTG9mwC1_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_M1TVNkcR, 0, m, &cVar_M1TVNkcR_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Hwby63Uh, 0, m, &cVar_Hwby63Uh_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_UAETENPN, 0, m, &cVar_UAETENPN_sendMessage);
  cMsg_Ibqb3JUG_sendMessage(_c, 0, m);
  cMsg_V3fQPMCn_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_tl94wXNj, 0, m, &cVar_tl94wXNj_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Kkch5TV6, 0, m, &cVar_Kkch5TV6_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ZeaSYo0A, 0, m, &cVar_ZeaSYo0A_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_zCZLRCnr, 0, m, &cVar_zCZLRCnr_sendMessage);
  cMsg_gPrJ1Tkw_sendMessage(_c, 0, m);
  cMsg_iBmr3LFI_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_cq1esJeH, 0, m, &cVar_cq1esJeH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ZKRObMeT, 0, m, &cVar_ZKRObMeT_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_e2M7ElJd, 0, m, &cVar_e2M7ElJd_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_WHafkyuK, 0, m, &cVar_WHafkyuK_sendMessage);
  cMsg_1eaWK3nN_sendMessage(_c, 0, m);
  cMsg_XLdBdUNL_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Kb0Ni9zK, 0, m, &cVar_Kb0Ni9zK_sendMessage);
  cMsg_9CwOr6yd_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_qCb3MdoT, 0, m, &cVar_qCb3MdoT_sendMessage);
  cMsg_hjbEBTSP_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_uYEr6xUh, 0, m, &cVar_uYEr6xUh_sendMessage);
  cMsg_wRz9D0OU_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_xKuXDpCU, 0, m, &cVar_xKuXDpCU_sendMessage);
  cMsg_PuGy9jUY_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Vq2UwYeb, 0, m, &cVar_Vq2UwYeb_sendMessage);
  cMsg_Sylzi5aC_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_g3sRcTjp, 0, m, &cVar_g3sRcTjp_sendMessage);
  cMsg_OqlN4PjH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_XljBVIzq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PtgtWpTU, HV_BINOP_MULTIPLY, 0, m, &cBinop_PtgtWpTU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_UBUSRrY9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_D6tvlYq4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_jXZPYKxN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_0exEOhEU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_FcRmVZYH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_UILGO926_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_CJCnb0Ch_sendMessage);
  cMsg_gayYjyQz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_fTKKzfZa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zgVTbFNY, HV_BINOP_MULTIPLY, 0, m, &cBinop_zgVTbFNY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_QUZSafhF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_ORih78k1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_tiEe4one_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kxegmS1m, HV_BINOP_MULTIPLY, 1, m, &cBinop_kxegmS1m_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_IIz5rCWw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_W6s1qoDe_sendMessage);
  cMsg_jL3gFd5E_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_KXJmXbHe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_90MZF72O, HV_BINOP_MULTIPLY, 0, m, &cBinop_90MZF72O_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_SVF7dnRB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xV167CVQ_sendMessage(_c, 0, m);
  cMsg_lyLuVu5p_sendMessage(_c, 0, m);
  cMsg_4ii2vutx_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_1C6xrWjL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_37EK88Zr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_BRzULTLn_sendMessage);
  cMsg_ar1HjIjP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_sPZIURtY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SkdJY9ci, 0, m, &cVar_SkdJY9ci_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_PChKCR7d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_d7ZKXTBN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_W8T7vpBx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_qLe4iSd0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_C186DmlN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eo5NiluP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_clxEn92I_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_3xwlnTFE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6a4uoYqO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ar444wv2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kLq57UHF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_cufhi6NL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dnhppSAQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dsxQfxuQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Mx47VzSq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_1YMI8Ry6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kEcCk9Rq, HV_BINOP_MULTIPLY, 0, m, &cBinop_kEcCk9Rq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_gYpqnUr5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_DvW9WMRz_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_P7NjEfL2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_CC2V8Gw9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_6qBtrkkQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_y0Ag82V1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_8uzfXi45_sendMessage);
  cMsg_9XovuwE5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_fgJIGKM7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VlvsT3E5, HV_BINOP_MULTIPLY, 0, m, &cBinop_VlvsT3E5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_fFJag43t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_452fOwPF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_hPLvPMer_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TZjzXUhV, HV_BINOP_MULTIPLY, 1, m, &cBinop_TZjzXUhV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Ph8ixbgW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_RNPRkyOy_sendMessage);
  cMsg_PaYYyxki_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_GWJXzfeF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LwzrzpXc, HV_BINOP_MULTIPLY, 0, m, &cBinop_LwzrzpXc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Lq7Coeq1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ArpFSJBF_sendMessage(_c, 0, m);
  cMsg_Bqr7FKJ4_sendMessage(_c, 0, m);
  cMsg_cuKreM0V_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_VrNmnjvD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_R4cruUEO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_KEBZRgIf_sendMessage);
  cMsg_ekyVBvAC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_hXpY2LJD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GugVWXAJ, 0, m, &cVar_GugVWXAJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_O5f2g90P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_sPUu7Bp6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_qZjtV9eP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_ZYIrfRZw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_GgcntOSp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EgAOI3MD, 0, m, &cVar_EgAOI3MD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_W4WXti8o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_zVQ8Hsq6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_5oRQooY3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_yTMzL9K2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_MDcRHa4j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_z24QBIWP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_leVCLEx6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_96KIEGzE, 0, m, &cVar_96KIEGzE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_KiPw5DIC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_6r6wOwCv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Esx5cZUy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_uF2ntFlN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_3qTsLV7b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_q2MDMfKe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_xAX4PBsL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wI7SaFpj, 0, m, &cVar_wI7SaFpj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_tWpfWKUV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_En2hQ15v_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_fPXIKBaG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_cKDxG0YX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_DuHLNSnR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Zqe9HGtl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Mn9BiI2z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_zYoIRRTH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_aSQUXB0X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_POK2YRng_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_zzgHUNL0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_066e1n8y_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_dO9arZNb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_ZIKTQvTw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Uc2g3iSq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_wB7ODXO4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_ydV5PWVu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_QUfmqkqA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_mhpqg7uO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_uaUfOjM1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_pJhxmfLo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_teopDrxg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_IJeuRxRH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_w6k2ZTvi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_IIiKrnLe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Qs2G3Rdq_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_FL3NGR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_rrRAyd3l, VOf(Bf0));
    __hv_line_f(&sLine_twZiGgGN, VOf(Bf1));
    __hv_line_f(&sLine_MqKv7Eak, VOf(Bf2));
    __hv_line_f(&sLine_76RpBgLX, VOf(Bf3));
    __hv_line_f(&sLine_D77gyQTR, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_YU3VCAIj, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_mtnYvZby, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_neD3RYMP, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_lKSAJPHL, VOf(Bf1));
    __hv_line_f(&sLine_CtYixTqs, VOf(Bf0));
    __hv_line_f(&sLine_AnilS9Bf, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_6BOoTdpM, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_6puHlmZj, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_mHoht1b8, VOf(Bf5));
    __hv_line_f(&sLine_E6pS4mir, VOf(Bf1));
    __hv_line_f(&sLine_tjPS3d21, VOf(Bf2));
    __hv_line_f(&sLine_yiREDD1z, VOf(Bf4));
    __hv_line_f(&sLine_j7WLhYOK, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_uNLP8QPK, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_noslubGs, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_3BcjWn4U, VOf(Bf6));
    __hv_line_f(&sLine_Ew6SYNmj, VOf(Bf2));
    __hv_line_f(&sLine_g7ayiPgm, VOf(Bf1));
    __hv_line_f(&sLine_H9eeAmXw, VOf(Bf5));
    __hv_line_f(&sLine_MKlYNoSv, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_CMepDkNH, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_HJHEcp1I, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_4SbpfdPS, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_Y7i0X1u3, VOf(Bf2));
    __hv_line_f(&sLine_BWuJnSTy, VOf(Bf6));
    __hv_line_f(&sLine_3NGDH9nc, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_Q5s7tPlE, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_rGPVjyHQ, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_lzNGt3BA, VOf(Bf8));
    __hv_line_f(&sLine_XTM74WSO, VOf(Bf2));
    __hv_line_f(&sLine_ok0C4HoQ, VOf(Bf1));
    __hv_line_f(&sLine_mdCI1r9J, VOf(Bf7));
    __hv_line_f(&sLine_PiO2EgoH, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_85U6p8kQ, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_dykhsmge, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_mOw1kwCd, VOf(Bf9));
    __hv_phasor_k_f(&sPhasor_y3pWWMry, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf8), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf2), VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_XH1YjBX4, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf10), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf2), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf1), VIf(Bf10), VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_neg_f(VIf(Bf1), VOf(Bf8));
    __hv_add_f(VIf(Bf8), VIf(Bf10), VOf(Bf8));
    __hv_varread_f(&sVarf_0U5u95Cz, VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_c6CGK9o7, VOf(Bf8));
    __hv_rpole_f(&sRPole_Y7IOTK6N, VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_eejh9GHF, VOf(Bf1));
    __hv_mul_f(VIf(Bf10), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_Qt0A8i22, VOf(Bf10));
    __hv_rpole_f(&sRPole_4md2bTWF, VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_tabhead_f(&sTabhead_OYW43Ixx, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf2), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_TLDNkXzt, VOf(Bf1));
    __hv_mul_f(VIf(Bf10), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_hBXmsBJy, VOf(Bf10));
    __hv_min_f(VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf10), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf2));
    __hv_varread_f(&sVarf_FzNRzPa6, VOf(Bf10));
    __hv_zero_f(VOf(Bf11));
    __hv_lt_f(VIf(Bf2), VIf(Bf11), VOf(Bf11));
    __hv_and_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf2), VIf(Bf11), VOf(Bf11));
    __hv_cast_fi(VIf(Bf11), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_Z969HtnV, VIi(Bi1), VOf(Bf11));
    __hv_tabread_if(&sTabread_MIASwqWl, VIi(Bi0), VOf(Bf10));
    __hv_sub_f(VIf(Bf11), VIf(Bf10), VOf(Bf11));
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf11), VIf(Bf2), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_n95iWa1G, VOf(Bf2));
    __hv_mul_f(VIf(Bf10), VIf(Bf2), VOf(Bf11));
    __hv_fma_f(VIf(Bf3), VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_tabhead_f(&sTabhead_mQrTt0BC, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf12), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_gVqyuPUw, VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_OTz5TTiU, VOf(Bf8));
    __hv_min_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf12), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf12));
    __hv_varread_f(&sVarf_wtBPylsH, VOf(Bf8));
    __hv_zero_f(VOf(Bf13));
    __hv_lt_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_and_f(VIf(Bf8), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_cast_fi(VIf(Bf13), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_LwbJZoDJ, VIi(Bi1), VOf(Bf13));
    __hv_tabread_if(&sTabread_yOBLvSC9, VIi(Bi0), VOf(Bf8));
    __hv_sub_f(VIf(Bf13), VIf(Bf8), VOf(Bf13));
    __hv_sub_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf13), VIf(Bf12), VIf(Bf8), VOf(Bf8));
    __hv_mul_f(VIf(Bf2), VIf(Bf8), VOf(Bf2));
    __hv_fma_f(VIf(Bf9), VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_7lTxxPuX, VOf(Bf9));
    __hv_fma_f(VIf(Bf9), VIf(Bf8), VIf(Bf5), VOf(Bf5));
    __hv_tabwrite_f(&sTabwrite_UGbqCpQu, VIf(Bf5));
    __hv_fma_f(VIf(Bf10), VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_QEAJ4geC, VIf(Bf3));
    __hv_varwrite_f(&sVarf_tSQtPspG, VIf(Bf11));
    __hv_line_f(&sLine_WUTeUERH, VOf(Bf11));
    __hv_phasor_k_f(&sPhasor_A0zp7kID, VOf(Bf3));
    __hv_var_k_f(VOf(Bf9), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_abs_f(VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf3), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf9), VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_kWehlBE9, VOf(Bf3));
    __hv_var_k_f(VOf(Bf9), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf5), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_mul_f(VIf(Bf3), VIf(Bf5), VOf(Bf3));
    __hv_mul_f(VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_neg_f(VIf(Bf3), VOf(Bf10));
    __hv_add_f(VIf(Bf10), VIf(Bf5), VOf(Bf10));
    __hv_varread_f(&sVarf_RdY48TDT, VOf(Bf9));
    __hv_mul_f(VIf(Bf10), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_0MPkzyKO, VOf(Bf10));
    __hv_rpole_f(&sRPole_1z4Q12Sg, VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_neGDFWv3, VOf(Bf3));
    __hv_mul_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_Pcy1dl4X, VOf(Bf5));
    __hv_rpole_f(&sRPole_DVU04Yib, VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_tabhead_f(&sTabhead_euHUqoxN, VOf(Bf3));
    __hv_var_k_f_r(VOf(Bf9), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_rYNkRQIl, VOf(Bf3));
    __hv_mul_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_l9TUCfS0, VOf(Bf5));
    __hv_min_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_zero_f(VOf(Bf3));
    __hv_max_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_floor_f(VIf(Bf3), VOf(Bf9));
    __hv_varread_f(&sVarf_LlRku39s, VOf(Bf5));
    __hv_zero_f(VOf(Bf8));
    __hv_lt_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_and_f(VIf(Bf5), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_cast_fi(VIf(Bf8), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_99mARNEn, VIi(Bi1), VOf(Bf8));
    __hv_tabread_if(&sTabread_x1M9b0nv, VIi(Bi0), VOf(Bf5));
    __hv_sub_f(VIf(Bf8), VIf(Bf5), VOf(Bf8));
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf8), VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_WYDF5Jh2, VOf(Bf9));
    __hv_mul_f(VIf(Bf5), VIf(Bf9), VOf(Bf8));
    __hv_fma_f(VIf(Bf0), VIf(Bf11), VIf(Bf8), VOf(Bf8));
    __hv_tabhead_f(&sTabhead_nidvomRH, VOf(Bf3));
    __hv_var_k_f_r(VOf(Bf12), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf3), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_uICnLuHu, VOf(Bf3));
    __hv_mul_f(VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_b5hegUeA, VOf(Bf10));
    __hv_min_f(VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_zero_f(VOf(Bf3));
    __hv_max_f(VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf12), VIf(Bf3), VOf(Bf3));
    __hv_floor_f(VIf(Bf3), VOf(Bf12));
    __hv_varread_f(&sVarf_2p7296fN, VOf(Bf10));
    __hv_zero_f(VOf(Bf13));
    __hv_lt_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_and_f(VIf(Bf10), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_cast_fi(VIf(Bf13), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_bNBDYjl0, VIi(Bi1), VOf(Bf13));
    __hv_tabread_if(&sTabread_yIzEOlF2, VIi(Bi0), VOf(Bf10));
    __hv_sub_f(VIf(Bf13), VIf(Bf10), VOf(Bf13));
    __hv_sub_f(VIf(Bf3), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf13), VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf9));
    __hv_fma_f(VIf(Bf11), VIf(Bf6), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_AD6NOWBN, VOf(Bf11));
    __hv_fma_f(VIf(Bf11), VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_tabwrite_f(&sTabwrite_scy2FQ2c, VIf(Bf6));
    __hv_fma_f(VIf(Bf5), VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_iCvHHwZP, VIf(Bf0));
    __hv_varwrite_f(&sVarf_O8XggNXK, VIf(Bf8));
    __hv_line_f(&sLine_iAymR6PP, VOf(Bf8));
    __hv_phasor_k_f(&sPhasor_gDVwjPQv, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_abs_f(VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf0), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf11), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_uVEHIEzW, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf0), VIf(Bf6), VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_neg_f(VIf(Bf0), VOf(Bf5));
    __hv_add_f(VIf(Bf5), VIf(Bf6), VOf(Bf5));
    __hv_varread_f(&sVarf_Ry6ZqjKU, VOf(Bf11));
    __hv_mul_f(VIf(Bf5), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_fzlq2bHd, VOf(Bf5));
    __hv_rpole_f(&sRPole_Qqu152HM, VIf(Bf11), VIf(Bf5), VOf(Bf5));
    __hv_add_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_iu7zgJ13, VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_jzmkHT9k, VOf(Bf6));
    __hv_rpole_f(&sRPole_xNmNNzat, VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_tabhead_f(&sTabhead_olOAcrwO, VOf(Bf0));
    __hv_var_k_f_r(VOf(Bf11), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_yAN3DImb, VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_y51AZSzI, VOf(Bf6));
    __hv_min_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_zero_f(VOf(Bf0));
    __hv_max_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_sub_f(VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_floor_f(VIf(Bf0), VOf(Bf11));
    __hv_varread_f(&sVarf_h6rZl739, VOf(Bf6));
    __hv_zero_f(VOf(Bf10));
    __hv_lt_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_and_f(VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_cast_fi(VIf(Bf10), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_bJT3oNrx, VIi(Bi1), VOf(Bf10));
    __hv_tabread_if(&sTabread_CLgoSV0t, VIi(Bi0), VOf(Bf6));
    __hv_sub_f(VIf(Bf10), VIf(Bf6), VOf(Bf10));
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_fma_f(VIf(Bf10), VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_FmeKWVor, VOf(Bf11));
    __hv_mul_f(VIf(Bf6), VIf(Bf11), VOf(Bf10));
    __hv_fma_f(VIf(Bf4), VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_tabhead_f(&sTabhead_IA5d9Xyx, VOf(Bf0));
    __hv_var_k_f_r(VOf(Bf12), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf0), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_fJlfZtxT, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_hLYhbnsF, VOf(Bf5));
    __hv_min_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_zero_f(VOf(Bf0));
    __hv_max_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_sub_f(VIf(Bf12), VIf(Bf0), VOf(Bf0));
    __hv_floor_f(VIf(Bf0), VOf(Bf12));
    __hv_varread_f(&sVarf_LUnfpqnN, VOf(Bf5));
    __hv_zero_f(VOf(Bf13));
    __hv_lt_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_and_f(VIf(Bf5), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_cast_fi(VIf(Bf13), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_7C100urG, VIi(Bi1), VOf(Bf13));
    __hv_tabread_if(&sTabread_MXK7JNEF, VIi(Bi0), VOf(Bf5));
    __hv_sub_f(VIf(Bf13), VIf(Bf5), VOf(Bf13));
    __hv_sub_f(VIf(Bf0), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf13), VIf(Bf12), VIf(Bf5), VOf(Bf5));
    __hv_mul_f(VIf(Bf11), VIf(Bf5), VOf(Bf11));
    __hv_fma_f(VIf(Bf8), VIf(Bf7), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_NKY5izPI, VOf(Bf8));
    __hv_fma_f(VIf(Bf8), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_tabwrite_f(&sTabwrite_C4GeiriC, VIf(Bf7));
    __hv_fma_f(VIf(Bf6), VIf(Bf8), VIf(Bf4), VOf(Bf4));
    __hv_tabwrite_f(&sTabwrite_vAGiRPVF, VIf(Bf4));
    __hv_varwrite_f(&sVarf_jokIo9ta, VIf(Bf10));
    __hv_varwrite_f(&sVarf_PwOTWyeZ, VIf(Bf2));
    __hv_varwrite_f(&sVarf_xuNyUIJk, VIf(Bf9));
    __hv_varwrite_f(&sVarf_0oGBtuHn, VIf(Bf11));
    __hv_varread_f(&sVarf_tSQtPspG, VOf(Bf11));
    __hv_varread_f(&sVarf_O8XggNXK, VOf(Bf9));
    __hv_varread_f(&sVarf_jokIo9ta, VOf(Bf2));
    __hv_add_f(VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf11), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf2), VIf(O0), VOf(O0));
    __hv_varread_f(&sVarf_PwOTWyeZ, VOf(Bf2));
    __hv_varread_f(&sVarf_xuNyUIJk, VOf(Bf11));
    __hv_varread_f(&sVarf_0oGBtuHn, VOf(Bf9));
    __hv_add_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf2), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf9), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_FL3NGR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_FL3NGR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
